import Layout from "@/components/layout/Layout";
import Link from "next/link";
import Contacting from "@/components/custom/Contact";

export const metadata = {
    title: "Contact | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function Contact() {
    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Contact Us">
                <div>
                    <section className="contact__area">
                        <div className="container">
                            <div className="row mb-70">
                                <div className="col-lg-5">
                                    <div className="contact__content">
                                        <div className="section-title mb-30">
                                            <span className="sub-title">
                                                GET <span className="title-color">IN TOUCH</span>
                                            </span>
                                            <h2 className="title">Let's Talk</h2>
                                            <p>
                                                Have a question about a service, pricing, or case study? Send us a
                                                message and we'll provide all the answers you need!
                                            </p>
                                        </div>
                                        <div className="contact__info">
                                            <ul className="list-wrap">
                                                <li>
                                                    <div className="icon">
                                                        <i className="flaticon-pin" />
                                                    </div>
                                                    <div className="content">
                                                        <h4 className="title">Address</h4>
                                                        <p>
                                                            <Link
                                                                href="https://maps.app.goo.gl/3vpv8Y9pSTtpcNGB6"
                                                                target="_blank"
                                                            >
                                                                Suite B, 1934 N. Druid Hills Rd, Brookhaven, GA 30319,
                                                                USA
                                                            </Link>
                                                        </p>
                                                    </div>
                                                </li>
                                                <li>
                                                    <div className="icon">
                                                        <i className="flaticon-phone-call" />
                                                    </div>
                                                    <div className="content">
                                                        <h4 className="title">Phone</h4>
                                                        <Link href="tel:+14702604117">(470) 260-4117</Link>
                                                    </div>
                                                </li>
                                                <li>
                                                    <div className="icon">
                                                        <i className="flaticon-mail" />
                                                    </div>
                                                    <div className="content">
                                                        <h4 className="title">Email</h4>
                                                        <Link href="mailto:support@rankrunners.net">
                                                            support@rankrunners.net
                                                        </Link>
                                                    </div>
                                                </li>
                                            </ul>
                                        </div>
                                        {/* <div className="contact__left mb-30">
                                            <ul>
                                                <li>
                                                    We'll increase your company website's organic search ranking and
                                                    visibility in Google search
                                                </li>
                                                <li>
                                                    This increased brand exposure will help attract and reel in
                                                    thousands of brand new customers
                                                </li>
                                                <li>
                                                    You will experience a higher bottom line, increased ROI and better
                                                    position yourself for sustainable, organic growth
                                                </li>
                                            </ul>
                                        </div>
                                        <div className="section-title">
                                            <p>Are you ready to outrun your competitors?</p>
                                        </div> */}
                                    </div>
                                </div>
                                <div className="col-lg-7">
                                    <Contacting />
                                </div>
                            </div>
                            <div className="row">
                                <div className="col-lg-12">
                                    <div className="contact-map">
                                        <iframe
                                            src="https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d3105.090533713237!2d-84.34295258493827!3d33.83509628065662!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x88f507b69aa2e0e3:0x51ce91157771e43d!2sRankRunners!5e0!3m2!1sen!2sus!4v1685560274134!5m2!1sen!2sus"
                                            allowFullScreen
                                            loading="lazy"
                                        />
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
            </Layout>
        </>
    );
}
