import Layout from "@/components/layout/Layout";
import Callback1 from "@/components/sections/Callback1";
import CaseStudyDetail from "@/components/custom/CaseStudyDetail";

export const metadata = {
    title: "Case Study - Atlas Aviation | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ProjectDetails() {
    let slug = "atlas-aviation";

    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Case Study: Atlas Aviation">
                <div>
                    <section className="project__details-area">
                        <div className="container">
                            <div className="project__details-wrap">
                                <CaseStudyDetail slug={slug} />
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <h2>The Challenge We Faced</h2>
                                            <p>
                                                Atlas Aviation, a premier provider of private jet charter and flight
                                                school services, faced the challenge of improving their online
                                                visibility and client engagement amidst a crowded and competitive
                                                market. Despite their industry expertise and high-quality services,
                                                their website was underperforming in search engine rankings, hampering
                                                their ability to attract new clients. The site was outdated, slow, and
                                                not optimized for search engines, which led to low organic traffic and
                                                poor user engagement.
                                            </p>
                                            <p>
                                                RankRunners was tasked with overhauling Atlas Aviation’s website and
                                                implementing a robust SEO strategy aimed at enhancing their online
                                                presence and driving more qualified leads to their business.
                                            </p>
                                            <h2>The Strategy We Applied</h2>
                                            <h5>Comprehensive Website Overhaul:</h5>
                                            <p>
                                                RankRunners began by completely redesigning Atlas Aviation’s website. We
                                                transitioned the site from its old and sluggish platform to a modern,
                                                high-performance framework. The new design focused on providing a sleek,
                                                professional look that aligns with Atlas Aviation’s brand while
                                                improving user experience. Key enhancements included faster load times,
                                                a responsive design for mobile devices, and a more intuitive navigation
                                                system to facilitate better client interactions.
                                            </p>
                                            <h5>Targeted SEO Campaign:</h5>
                                            <p>
                                                To address the low search engine visibility, we implemented a targeted
                                                SEO campaign. This involved a detailed keyword analysis to identify
                                                high-value search terms such as “private jet charter,” “aviation
                                                instruction services,” and “tampa aircraft rental”. We optimized the
                                                website’s content with these keywords, updated meta tags, and improved
                                                on-page SEO elements to enhance search engine rankings.
                                            </p>
                                            <h5>Local and Industry-Specific SEO:</h5>
                                            <p>
                                                Given the nature of Atlas Aviation’s services, local and
                                                industry-specific SEO was critical. We optimized the Google My Business
                                                profile, ensuring it featured accurate information and high-quality
                                                images. Additionally, we created location-based content and secured
                                                backlinks from relevant industry sources to improve local search
                                                visibility and establish authority in the aviation sector.
                                            </p>
                                            <h5>Regular Progress Reviews:</h5>
                                            <p>
                                                RankRunners scheduled bi-weekly progress reviews with Atlas Aviation to
                                                keep them informed about the performance of the digital marketing
                                                strategy. During these meetings, we presented detailed analytical
                                                reports showing improvements in website traffic, search rankings, and
                                                user engagement. This approach allowed for transparent communication and
                                                continuous optimization of the strategy based on real-time data.
                                            </p>
                                            <h5>Enhanced Social Media Integration:</h5>
                                            <p>
                                                To complement the website and SEO efforts, we integrated social media
                                                strategies into Atlas Aviation’s overall marketing plan. We developed
                                                engaging content for platforms like LinkedIn and Instagram to showcase
                                                their services and client success stories, driving additional traffic to
                                                the revamped website and increasing brand awareness.
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <Callback1 />
                <div>
                    <section className="project__details-area-one">
                        <div className="container">
                            <div className="project__details-wrap">
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <div className="project__details-inner">
                                                <div className="row align-items-center">
                                                    <div className="col-lg-12">
                                                        <h2>The Results We Provided</h2>
                                                        <p>
                                                            The concerted efforts of RankRunners and Atlas Aviation
                                                            resulted in a transformative impact on their online presence
                                                            and business performance. The revamped website, combined
                                                            with a targeted SEO and social media strategy, led to
                                                            significant improvements in key metrics.
                                                        </p>
                                                        <h3>Key Achievements</h3>
                                                        <h5>Revamped Website:</h5>
                                                        <p>
                                                            The new site provided a more modern, user-friendly
                                                            experience with enhanced functionality and faster
                                                            performance.
                                                        </p>
                                                        <h5>Improved Search Rankings:</h5>
                                                        <p>
                                                            Atlas Aviation’s website moved from an average search
                                                            position of #40 to the top 10 positions for critical search
                                                            terms, significantly boosting visibility.
                                                        </p>
                                                        <h5>Enhanced Local and Industry Visibility:</h5>
                                                        <p>
                                                            The optimized Google My Business profile and
                                                            industry-specific content increased local search visibility
                                                            by 70% and established Atlas Aviation as a leading authority
                                                            in the aviation sector.
                                                        </p>
                                                        <h5>Increased Engagement:</h5>
                                                        <p>
                                                            The integrated social media campaigns contributed to a 50%
                                                            increase in website traffic and higher engagement rates
                                                            across social media platforms.
                                                        </p>
                                                    </div>
                                                    <div className="col-lg-6 order-lg-1">
                                                        <div className="project__details-inner-img">
                                                            <img
                                                                src="/assets/img/case-study/atlas-aviation-1.png"
                                                                alt=""
                                                            />
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-6">
                                                        <div className="project__details-inner-content">
                                                            <div className="content-inner">
                                                                <h4>Before</h4>
                                                                <div className="row">
                                                                    <div className="col-md-6">
                                                                        <div className="case-study-cta-ba">
                                                                            <h3>Image Coming Soon</h3>
                                                                        </div>
                                                                    </div>
                                                                    <div className="col-md-6 about__list-box">
                                                                        <ul className="list-wrap">
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Outdated Website
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                #40 Avg. Search Position
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Low Local Visibility
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Limited Social Media Engagement
                                                                            </li>
                                                                        </ul>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                            <div className="content-inner">
                                                                <h4>After</h4>
                                                                <div className="row">
                                                                    <div className="col-md-6">
                                                                        <div className="case-study-cta-ba">
                                                                            <video
                                                                                src="/assets/img/case-study/atlas-aviation.webm"
                                                                                autoPlay
                                                                                muted
                                                                                loop
                                                                                alt=""
                                                                            />
                                                                        </div>
                                                                    </div>
                                                                    <div className="col-md-6 about__list-box">
                                                                        <ul className="list-wrap">
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Modernized Website
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Top 10 Avg. Search Position
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                +70% Local Visibility
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                +50% Website Traffic
                                                                            </li>
                                                                        </ul>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-12 order-last">
                                                        <p>
                                                            The successful partnership between Atlas Aviation and
                                                            RankRunners highlights our ability to deliver impactful
                                                            results through a comprehensive approach to website design,
                                                            SEO, and digital marketing. By addressing key challenges and
                                                            implementing a tailored strategy, RankRunners significantly
                                                            enhanced Atlas Aviation’s online presence, driving more
                                                            qualified leads and reinforcing their position as a top
                                                            player in the private aviation industry.
                                                        </p>

                                                        <p>
                                                            This case study underscores RankRunners' commitment to
                                                            achieving measurable improvements for clients and
                                                            demonstrates the effectiveness of a well-rounded strategy in
                                                            surpassing business goals.
                                                        </p>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
            </Layout>
        </>
    );
}
