import Layout from "@/components/layout/Layout";
import Callback1 from "@/components/sections/Callback1";
import CaseStudyDetail from "@/components/custom/CaseStudyDetail";

export const metadata = {
    title: "Case Study - Discord Center | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ProjectDetails() {
    let slug = "discord-center";

    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Case Study: Discord Center">
                <div>
                    <section className="project__details-area">
                        <div className="container">
                            <div className="project__details-wrap">
                                <CaseStudyDetail slug={slug} />
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <h2>The Challenge We Faced</h2>
                                            <p>
                                                Discord Center struggled with a fragmented user experience and low
                                                visibility in search results, limiting its growth potential. Our agency
                                                tackled this by revamping the website’s structure for better navigation
                                                and implementing a targeted SEO strategy. This approach significantly
                                                enhanced their search engine ranking and user engagement, driving
                                                increased traffic and improving overall site performance.
                                            </p>
                                            <h2>The Strategy We Applied</h2>
                                            <h5>Website Revamp and Optimization:</h5>
                                            <p>
                                                We began by overhauling Discord Center’s existing website to address its
                                                fragmented user experience and performance issues. The website was
                                                migrated from its outdated framework to a modern, scalable architecture
                                                using Next.js. This transition enhanced server-side rendering,
                                                streamlined routing, and significantly improved site speed and
                                                responsiveness. Our team also redesigned the site’s layout to create a
                                                more intuitive and engaging user experience, ensuring that users could
                                                easily find and interact with Discord servers.
                                            </p>
                                            <h5>Targeted SEO Strategy:</h5>
                                            <p>
                                                To boost Discord Center’s visibility, we implemented a targeted SEO
                                                strategy focusing on high-value keywords and optimizing on-page content.
                                                This included refining meta tags, improving content relevance, and
                                                ensuring that each page was optimized for search engine algorithms. We
                                                also built high-quality backlinks and improved the site’s overall
                                                authority to enhance its ranking in search results, driving more organic
                                                traffic to the site.
                                            </p>
                                            <h5>Continuous Performance Monitoring and Reporting:</h5>
                                            <p>
                                                We established a routine of bi-weekly performance reviews to track
                                                progress and adjust strategies as needed. During these meetings, we
                                                provided detailed reports on key metrics such as traffic growth, keyword
                                                rankings, and user engagement. This approach ensured transparency and
                                                allowed us to make data-driven decisions to continuously optimize and
                                                refine our strategy for maximum impact.
                                            </p>
                                            <h5>Community Engagement and Feedback Integration:</h5>
                                            <p>
                                                To further align the site with user needs, we integrated feedback
                                                mechanisms and engaged with the Discord community to gather insights.
                                                This input was used to make iterative improvements, enhancing user
                                                satisfaction and retention. By aligning the website’s features with
                                                community expectations, we fostered a more engaged and loyal user base.
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <Callback1 />
                <div>
                    <section className="project__details-area-one">
                        <div className="container">
                            <div className="project__details-wrap">
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <div className="project__details-inner">
                                                <div className="row align-items-center">
                                                    <div className="col-lg-6 order-lg-1">
                                                        <div className="project__details-inner-img">
                                                            <img
                                                                src="/assets/img/case-study/discord-center-1.png"
                                                                alt=""
                                                            />
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-6">
                                                        <div className="project__details-inner-content">
                                                            <h2>The Results We Provided</h2>
                                                            <p>
                                                                The revitalization of Discord Center through our
                                                                targeted strategies led to remarkable improvements in
                                                                both performance and user engagement. The website
                                                                overhaul and SEO enhancements resulted in a substantial
                                                                increase in visibility and user interaction,
                                                                transforming Discord Center into a leading platform for
                                                                Discord server listings.
                                                            </p>

                                                            <div className="content-inner">
                                                                <h4>Before</h4>
                                                                <div className="row">
                                                                    <div className="col-md-6">
                                                                        <div className="case-study-cta-ba">
                                                                            <h3>Image Coming Soon</h3>
                                                                        </div>
                                                                    </div>
                                                                    <div className="col-md-6 about__list-box">
                                                                        <ul className="list-wrap">
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Outdated and fragmented website
                                                                                experience
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                #45 Avg. Search Position
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Low Domain Authority
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Limited user engagement and traffic
                                                                            </li>
                                                                        </ul>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                            <div className="content-inner">
                                                                <h4>After</h4>
                                                                <div className="row">
                                                                    <div className="col-md-6">
                                                                        <div className="case-study-cta-ba">
                                                                            <video
                                                                                src="/assets/img/case-study/discord-center.webm"
                                                                                autoPlay
                                                                                muted
                                                                                loop
                                                                                alt=""
                                                                            />
                                                                        </div>
                                                                    </div>
                                                                    <div className="col-md-6 about__list-box">
                                                                        <ul className="list-wrap">
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Streamlined and modernized website
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                #8 Avg. Search Position
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                +320% Domain Authority
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                +400% Growth in Monthly Traffic and User
                                                                                Engagement
                                                                            </li>
                                                                        </ul>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-12 order-last">
                                                        <p>
                                                            The comprehensive website revamp and strategic SEO
                                                            improvements not only elevated Discord Center’s search
                                                            engine rankings but also significantly enhanced user
                                                            experience and site performance. These changes have
                                                            positioned Discord Center as a top player in its niche,
                                                            resulting in a notable surge in traffic and engagement. This
                                                            case study illustrates our commitment to delivering
                                                            measurable outcomes and underscores the effectiveness of our
                                                            integrated approach to web development and SEO.
                                                        </p>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
            </Layout>
        </>
    );
}
