import Layout from "@/components/layout/Layout";
import Callback1 from "@/components/sections/Callback1";
import CaseStudyDetail from "@/components/custom/CaseStudyDetail";

export const metadata = {
    title: "Case Study - Hytale Server Hosting | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ProjectDetails() {
    let slug = "hytale-server-hosting";

    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Case Study: Hytale Server Hosting">
                <div>
                    <section className="project__details-area">
                        <div className="container">
                            <div className="project__details-wrap">
                                <CaseStudyDetail slug={slug} />
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <h2>The Challenge We Faced</h2>
                                            <p>
                                                Hytale Hosting faced the challenge of penetrating a highly competitive
                                                and saturated market with a relatively smaller budget, and less brand
                                                familiarity. RankRunners’ tasks involved carrying out a complete website
                                                overhaul and implementing a comprehensive SEO strategy with the ultimate
                                                goal of bringing Hytale Hosting to the top of the organic search results
                                                for relevant search terms.
                                            </p>
                                            <h2>The Strategy We Applied</h2>
                                            <h5>Website Overhaul:</h5>
                                            <p>
                                                RankRunners started at ground zero by completely revamping the original
                                                Hytale Hosting website. This was done by migrating the originally slow
                                                and buggy PHP-based website to a Next.js React-based framework which
                                                allowed for better server-side rendering, simplified routing, and better
                                                overall site performance. These infrastructural changes combined with
                                                many other SEO-focused content adjustments allowed Hytale Hosting to
                                                both appear and function as a worthy competitor against the seemingly
                                                insurmountable competition that the company was initially up against.
                                            </p>
                                            <h5>Visibility-Boosting SEO Campaign:</h5>
                                            <p>
                                                RankRunners initiated a comprehensive SEO campaign to boost Hytale
                                                Hosting’s organic search visibility. The focus was on strategically
                                                positioning Hytale Hosting in search engine results for key terms such
                                                as “hytale server hosting” and “hytale hosting,” allowing a company with
                                                a fraction of the budget of more-established, multi-purpose game server
                                                hosts to dominate relevant organic search terms and have a viable path
                                                to dominate their industry for years to come.
                                            </p>
                                            <h5>Bi-Weekly Progress Meetings:</h5>
                                            <p>
                                                RankRunners hosted routine bi-weekly progress meetings to keep Hytale
                                                Hosting informed about the effectiveness of their digital marketing
                                                efforts. Throughout these meetings, detailed analytical reports were
                                                presented which showcased the progress being made, areas of improvement,
                                                and recommended strategies for future growth. This allowed for full
                                                transparency and ongoing collaboration in refining and optimizing the
                                                ongoing strategy.
                                            </p>
                                            <h5>Referral Program:</h5>
                                            <p>
                                                We provided Hytale Hosting with an additional way to recoup their
                                                investment in our SEO and Web Dev/Design services by offering a monetary
                                                award for referring other businesses to RankRunners. As a result, many
                                                new clients have since also decided to work with RankRunners, resulting
                                                in further growth of our agency through word-of-mouth referrals.
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <Callback1 />
                <div>
                    <section className="project__details-area-one">
                        <div className="container">
                            <div className="project__details-wrap">
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <div className="project__details-inner">
                                                <div className="row align-items-center">
                                                    <div className="col-lg-6 order-lg-1">
                                                        <div className="project__details-inner-img">
                                                            <img
                                                                src="/assets/img/case-study/hytale-hosting-1.png"
                                                                alt=""
                                                            />
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-6">
                                                        <div className="project__details-inner-content">
                                                            <h2>The Results We Provided</h2>
                                                            <p>
                                                                The collaborative efforts between Hytale Hosting and
                                                                RankRunners produced outstanding results, including the
                                                                creation of a more user-friendly and SEO-adherent
                                                                website, infinitely higher search visibility, increased
                                                                domain authority and brand recognition, and an
                                                                exponential increase in average monthly revenue.
                                                            </p>

                                                            <div className="content-inner">
                                                                <h4>Before</h4>
                                                                <div className="row">
                                                                    <div className="col-md-6">
                                                                        <div className="case-study-cta-ba">
                                                                            <img
                                                                                src="/assets/img/case-study/hytale-hosting-before.png"
                                                                                alt=""
                                                                            />
                                                                        </div>
                                                                    </div>
                                                                    <div className="col-md-6 about__list-box">
                                                                        <ul className="list-wrap">
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Outdated Website
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                #32 Avg. Search Position
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Low Domain Authority
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Suboptimal Revenue
                                                                            </li>
                                                                        </ul>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                            <div className="content-inner">
                                                                <h4>After</h4>
                                                                <div className="row">
                                                                    <div className="col-md-6">
                                                                        <div className="case-study-cta-ba">
                                                                            <video
                                                                                src="/assets/img/case-study/hytale-server-hosting.webm"
                                                                                autoPlay
                                                                                muted
                                                                                loop
                                                                                alt=""
                                                                            />
                                                                        </div>
                                                                    </div>
                                                                    <div className="col-md-6 about__list-box">
                                                                        <ul className="list-wrap">
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Refined Website
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                #1 Avg. Search Position
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                +270% Domain Authority
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                +350% Annual Revenue
                                                                            </li>
                                                                        </ul>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-12 order-last">
                                                        <p>
                                                            The success story of Hytale Hosting in the Gameserver
                                                            hosting industry demonstrates RankRunners’ commitment to
                                                            consistently delivering tangible results. By executing a
                                                            flawless SEO strategy, providing transparent communication
                                                            throughout each bi-weekly meeting, and implementing a
                                                            complete design overhaul, RankRunners had a significant
                                                            impact upon Hytale Hosting’s future revenue growth and
                                                            business expansion.
                                                        </p>
                                                        <p>
                                                            This case study highlights our ability to deliver measurable
                                                            results, foster client satisfaction, and utilize referral
                                                            programs for mutual benefit between agency and client. The
                                                            collaborative efforts made by RankRunners and HytaleHosting
                                                            demonstrates the effectiveness of a comprehensive approach
                                                            to SEO and website design in not only achieving, but
                                                            surpassing business goals.
                                                        </p>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
            </Layout>
        </>
    );
}
