import Layout from "@/components/layout/Layout";
import Callback1 from "@/components/sections/Callback1";
import CaseStudyDetail from "@/components/custom/CaseStudyDetail";

export const metadata = {
    title: "Case Study | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ProjectDetails() {
    let slug = "jenni-bg-plumbing";

    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Case Study: Jenni BG Plumbing">
                <div>
                    <section className="project__details-area">
                        <div className="container">
                            <div className="project__details-wrap">
                                <CaseStudyDetail slug={slug} />
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <h2>The Challenge We Faced</h2>
                                            <p>
                                                Jenni BG Plumbing faced a critical challenge: they had no online
                                                presence and lacked a website, severely limiting their ability to
                                                attract and convert customers. In a competitive market where many
                                                competitors already had established online profiles, Jenni BG Plumbing
                                                needed a strategic overhaul. Our goal was to establish a strong online
                                                presence, optimize their local search visibility, and generate
                                                high-quality leads for their premium services.
                                            </p>
                                            <h2>The Strategy We Applied</h2>
                                            <h5>Website Creation and Optimization:</h5>
                                            <p>
                                                RankRunners initiated the creation of a new, fully functional website
                                                for Jenni BG Plumbing from scratch. We designed a visually appealing,
                                                mobile-responsive site that showcased their services and expertise
                                                effectively. The website was optimized for speed and usability, ensuring
                                                an excellent user experience and improved search engine rankings.
                                            </p>
                                            <h5>Google Business Profile Mastery:</h5>
                                            <p>
                                                We set up and optimized Jenni BG Plumbing's Google Business Profile to
                                                enhance their local search visibility. This included providing accurate
                                                business information, crafting compelling business descriptions, and
                                                managing customer reviews. We ensured the profile was regularly updated
                                                with new posts and promotions to engage local customers and boost local
                                                search rankings.
                                            </p>
                                            <h5>Precision Targeted Advertising:</h5>
                                            <p>
                                                RankRunners launched a targeted paid advertising campaign focusing on
                                                high-value services such as main water line and sewer line replacements.
                                                Instead of a broad approach, we emphasized the premium nature of these
                                                services to attract high-value clients. This strategy aimed to filter
                                                out lower-quality leads and concentrate efforts on acquiring customers
                                                willing to invest in premium services.
                                            </p>
                                            <h5>Relentless Performance Monitoring:</h5>
                                            <p>
                                                We continuously monitored the performance of the website and advertising
                                                campaigns to ensure effectiveness. Detailed reports were provided to
                                                Jenni BG Plumbing, highlighting key metrics such as website traffic,
                                                lead quality, and ad campaign performance. This approach allowed us to
                                                make data-driven adjustments and optimize strategies over time.
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <Callback1 />
                <div>
                    <section className="project__details-area-one">
                        <div className="container">
                            <div className="project__details-wrap">
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <div className="project__details-inner">
                                                <div className="row align-items-center">
                                                    <div className="col-lg-12">
                                                        <h2>The Results We Provided</h2>
                                                        <p>
                                                            The partnership between RankRunners and Jenni BG Plumbing
                                                            delivered impressive results:
                                                        </p>
                                                        <h5>Website Launch Success:</h5>
                                                        <p>
                                                            Jenni BG Plumbing now has a professional, fully functional
                                                            website that effectively represents their brand and
                                                            services.
                                                        </p>
                                                        <h5>Enhanced Local Visibility:</h5>
                                                        <p>
                                                            The optimized Google Business Profile resulted in improved
                                                            local search rankings and increased visibility among
                                                            potential customers in their service area.
                                                        </p>
                                                        <h5>High-Quality Leads:</h5>
                                                        <p>
                                                            The targeted advertising campaign successfully attracted
                                                            higher-value leads interested in premium services, leading
                                                            to a more efficient use of marketing resources and higher
                                                            conversion rates.
                                                        </p>
                                                        <h5>Revenue Boost</h5>
                                                        <p>
                                                            The focus on high-value services contributed to a
                                                            significant increase in revenue, demonstrating the
                                                            effectiveness of our targeted approach.
                                                        </p>
                                                    </div>
                                                    <div className="col-lg-6 order-lg-1">
                                                        <div className="project__details-inner-img">
                                                            <img
                                                                src="/assets/img/case-study/jenni-bg-plumbing-1.png"
                                                                alt=""
                                                            />
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-6">
                                                        <div className="project__details-inner-content">
                                                            <div className="content-inner">
                                                                <h4>Before</h4>
                                                                <div className="row">
                                                                    <div className="col-md-12">
                                                                        <div className="case-study-cta-ba">
                                                                            <h3>Image Coming Soon</h3>
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                            <div className="content-inner">
                                                                <h4>After</h4>
                                                                <div className="row">
                                                                    <div className="col-md-12">
                                                                        <div className="case-study-cta-ba">
                                                                            <video
                                                                                src="/assets/img/case-study/jenni-bg-plumbing.webm"
                                                                                autoPlay
                                                                                muted
                                                                                loop
                                                                                alt=""
                                                                            />
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-12 order-last">
                                                        <p>
                                                            This case study highlights RankRunners' ability to deliver
                                                            tailored solutions that address specific business
                                                            challenges. By establishing a strong online presence,
                                                            optimizing local search visibility, and focusing on
                                                            high-quality lead generation, we significantly enhanced
                                                            Jenni BG Plumbing's market position and revenue growth. The
                                                            results reflect our commitment to providing impactful SEO
                                                            and digital marketing solutions that drive tangible business
                                                            outcomes.
                                                        </p>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
            </Layout>
        </>
    );
}
