import Layout from "@/components/layout/Layout";
import Callback1 from "@/components/sections/Callback1";
import CaseStudyDetail from "@/components/custom/CaseStudyDetail";

export const metadata = {
    title: "Case Study - Multi Group Automotive | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ProjectDetails() {
    let slug = "multi-group-automotive";

    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Case Study: Multi Group Automotive">
                <div>
                    <section className="project__details-area">
                        <div className="container">
                            <div className="project__details-wrap">
                                <CaseStudyDetail slug={slug} />
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <h2>The Challenge We Faced</h2>
                                            <p>
                                                Multi Group Automotive faced the challenge of differentiating itself in
                                                a highly competitive automotive market with diverse service offerings.
                                                The company struggled with low organic search visibility and a website
                                                that was not user-friendly. RankRunners’ tasks included a full website
                                                overhaul and the implementation of a robust SEO strategy to enhance
                                                Multi Group Automotive's online presence and drive more organic traffic
                                                to the site.
                                            </p>
                                            <h2>The Strategy We Appliedc</h2>
                                            <h5>Website Overhaul:</h5>
                                            <p>
                                                RankRunners began by completely redesigning Multi Group Automotive's
                                                website. The original website was outdated and lacked a modern user
                                                interface. We transitioned the site to a more responsive and visually
                                                appealing platform, enhancing user experience with streamlined
                                                navigation and faster load times. These changes ensured that the website
                                                was optimized for both desktop and mobile users, improving overall site
                                                performance.
                                            </p>
                                            <h5>Comprehensive SEO Campaign:</h5>
                                            <p>
                                                RankRunners launched an extensive SEO campaign focused on optimizing
                                                Multi Group Automotive’s presence for key search terms such as “auto
                                                repair,” “car sales,” and “vehicle maintenance.” We implemented on-page
                                                SEO techniques, including keyword optimization, meta tag adjustments,
                                                and high-quality content creation. Off-page SEO efforts, such as
                                                link-building and social media integration, were also employed to boost
                                                the site’s domain authority and search engine rankings.
                                            </p>
                                            <h5>Regular Progress Reviews:</h5>
                                            <p>
                                                RankRunners conducted regular monthly progress meetings to keep Multi
                                                Group Automotive informed about the ongoing effectiveness of our SEO
                                                strategies. These meetings included detailed analytical reports
                                                highlighting key performance metrics, areas for improvement, and future
                                                strategies. This transparency fostered a collaborative environment,
                                                enabling continuous optimization and adjustment of our strategies.
                                            </p>
                                            <h5>Referral Program:</h5>
                                            <p>
                                                To further benefit Multi Group Automotive, we introduced a referral
                                                program that rewarded them for referring new clients to RankRunners.
                                                This initiative not only helped Multi Group Automotive to offset their
                                                investment in our services but also contributed to the growth of
                                                RankRunners through word-of-mouth referrals.
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <Callback1 />
                <div>
                    <section className="project__details-area-one">
                        <div className="container">
                            <div className="project__details-wrap">
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <div className="project__details-inner">
                                                <div className="row align-items-center">
                                                    <div className="col-lg-6 order-lg-1">
                                                        <div className="project__details-inner-img">
                                                            <img
                                                                src="/assets/img/case-study/multi-group-automotive-1.png"
                                                                alt=""
                                                            />
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-6">
                                                        <div className="project__details-inner-content">
                                                            <h2>The Results We Provided</h2>
                                                            <p>
                                                                The partnership between Multi Group Automotive and
                                                                RankRunners resulted in significant improvements in
                                                                website performance and online visibility. Our
                                                                collaborative efforts led to the creation of a
                                                                user-friendly, SEO-optimized website that achieved
                                                                higher search engine rankings, increased domain
                                                                authority, and boosted monthly revenue.
                                                            </p>

                                                            <div className="content-inner">
                                                                <h4>Before</h4>
                                                                <div className="row">
                                                                    <div className="col-md-6">
                                                                        <div className="case-study-cta-ba">
                                                                            <h3>Image Coming Soon</h3>
                                                                        </div>
                                                                    </div>
                                                                    <div className="col-md-6 about__list-box">
                                                                        <ul className="list-wrap">
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Outdated Website
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                #45 Avg. Search Position
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Low Domain Authority
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Suboptimal Revenue
                                                                            </li>
                                                                        </ul>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                            <div className="content-inner">
                                                                <h4>After</h4>
                                                                <div className="row">
                                                                    <div className="col-md-6">
                                                                        <div className="case-study-cta-ba">
                                                                            <video
                                                                                src="/assets/img/case-study/multi-group-automotive.webm"
                                                                                autoPlay
                                                                                muted
                                                                                loop
                                                                                alt=""
                                                                            />
                                                                        </div>
                                                                    </div>
                                                                    <div className="col-md-6 about__list-box">
                                                                        <ul className="list-wrap">
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Modernized Website
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                #3 Avg. Search Position
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                +300% Domain Authority
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                +400% Annual Revenue
                                                                            </li>
                                                                        </ul>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-12 order-last">
                                                        <p>
                                                            The success story of Multi Group Automotive showcases
                                                            RankRunners' dedication to delivering substantial results.
                                                            By executing an effective SEO strategy, maintaining
                                                            transparent communication, and overhauling the website
                                                            design, RankRunners significantly impacted Multi Group
                                                            Automotive’s revenue growth and market presence. This case
                                                            study exemplifies our ability to achieve and surpass
                                                            business goals, ensuring client satisfaction and fostering
                                                            long-term growth through innovative digital marketing
                                                            strategies.
                                                        </p>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
            </Layout>
        </>
    );
}
