import Layout from "@/components/layout/Layout";
import Callback1 from "@/components/sections/Callback1";
import CaseStudyDetail from "@/components/custom/CaseStudyDetail";

export const metadata = {
    title: "Case Study | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ProjectDetails() {
    let slug = "taqueria-del-mar";

    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Case Study: Taqueria del Mar">
                <div>
                    <section className="project__details-area">
                        <div className="container">
                            <div className="project__details-wrap">
                                <CaseStudyDetail slug={slug} />
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <h2>The Challenge We Faced</h2>
                                            <p>
                                                Taqueria Del Mar, a beloved local eatery, faced a complex crisis: they
                                                were struggling to differentiate themselves in a saturated market. Their
                                                location wasn’t attracting enough customers, and retaining them was
                                                proving even harder. With a limited budget, they needed a powerful
                                                strategy to capture attention and drive significant business growth.
                                            </p>
                                            <h2>The Strategy We Applied</h2>
                                            <h5>Website Overhaul:</h5>
                                            <p>
                                                We transformed Taqueria Del Mar’s website into a captivating,
                                                user-friendly platform. We revamped the design for visual appeal,
                                                optimized the layout for speed, and enhanced its search engine
                                                visibility. These changes ensured that their site not only attracted
                                                more visitors but also ranked higher in local search results.
                                            </p>
                                            <h5>Catering Strategy:</h5>
                                            <p>
                                                To cut through the local competition, we shifted Taqueria Del Mar’s
                                                focus to catering services. This allowed them to tap into higher-value
                                                opportunities and attract new clientele. We crafted compelling marketing
                                                materials that highlighted their catering offerings, setting them apart
                                                from local competitors and driving interest in their premium services.
                                            </p>
                                            <h5>Social Media Enhancement:</h5>
                                            <p>
                                                We revitalized their Instagram presence with dynamic content and
                                                targeted advertising. By creating engaging posts and actively
                                                interacting with the local community, we significantly boosted their
                                                online visibility and drew more traffic to their website. This increased
                                                engagement helped build a loyal customer base and enhanced their
                                                catering appeal.
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <Callback1 />
                <div>
                    <section className="project__details-area-one">
                        <div className="container">
                            <div className="project__details-wrap">
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <div className="project__details-inner">
                                                <div className="row align-items-center">
                                                    <div className="col-lg-12">
                                                        <h2>The Results We Provided</h2>
                                                        <h5>Elevated Online Presence:</h5>
                                                        <p>
                                                            The revamped website and SEO improvements dramatically
                                                            increased Taqueria Del Mar’s visibility in local search
                                                            results, making them easier to find online.
                                                        </p>
                                                        <h5>Successful Catering Initiative:</h5>
                                                        <p>
                                                            The shift to catering paid impressive dividends. They
                                                            experienced a substantial rise in catering orders, which not
                                                            only set them apart but also significantly boosted their
                                                            revenue.
                                                        </p>
                                                        <h5>Enhanced Social Media Impact:</h5>
                                                        <p>
                                                            Their Instagram following surged, and engagement levels
                                                            soared. This spike in social media activity drove more
                                                            visitors to their website and heightened interest in their
                                                            catering services.
                                                        </p>
                                                    </div>
                                                    <div className="col-lg-6 order-lg-1">
                                                        <div className="project__details-inner-img">
                                                            <img
                                                                src="/assets/img/case-study/taqueria-del-mar-1.png"
                                                                alt=""
                                                            />
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-6">
                                                        <div className="project__details-inner-content">
                                                            <div className="content-inner">
                                                                <h4>Before</h4>
                                                                <div className="row">
                                                                    <div className="col-md-12">
                                                                        <div className="case-study-cta-ba">
                                                                            <img
                                                                                src="/assets/img/case-study/taqueria-del-mar-before.png"
                                                                                alt=""
                                                                            />
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                            <div className="content-inner">
                                                                <h4>After</h4>
                                                                <div className="row">
                                                                    <div className="col-md-12">
                                                                        <div className="case-study-cta-ba">
                                                                            <video
                                                                                src="/assets/img/case-study/taqueria-del-mar.webm"
                                                                                autoPlay
                                                                                muted
                                                                                loop
                                                                                alt=""
                                                                            />
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-12 order-last">
                                                        <p>
                                                            Overall, RankRunners empowered Taqueria Del Mar to conquer
                                                            their market challenges by focusing on a targeted catering
                                                            strategy and enhancing their online presence. Our approach
                                                            delivered transformative results, driving their success and
                                                            elevating their business to new heights.
                                                        </p>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
            </Layout>
        </>
    );
}
