import Layout from "@/components/layout/Layout";
import Callback1 from "@/components/sections/Callback1";
import CaseStudyDetail from "@/components/custom/CaseStudyDetail";

export const metadata = {
    title: "Case Study | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ProjectDetails() {
    let slug = "the-spark-coffee";

    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Case Study: The Spark Coffee">
                <div>
                    <section className="project__details-area">
                        <div className="container">
                            <div className="project__details-wrap">
                                <CaseStudyDetail slug={slug} />
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <h2>The Challenge We Faced</h2>
                                            <p>
                                                The Spark, a local café with a strong community presence, was grappling
                                                with several digital challenges. Despite their excellent reputation and
                                                loyal customer base, their website was underperforming in search engine
                                                rankings, leading to limited online visibility and reduced foot traffic.
                                                The site suffered from outdated design, slow load times, and ineffective
                                                SEO practices. RankRunners was tasked with revitalizing The Spark's
                                                online presence to better reflect their brand, attract more customers,
                                                and enhance their search engine rankings.
                                            </p>
                                            <h2>The Strategy We Applied</h2>
                                            <h5>Website Revamp:</h5>
                                            <p>
                                                RankRunners initiated a comprehensive overhaul of The Spark's website.
                                                We migrated the site from its outdated platform to a modern, responsive
                                                framework, significantly improving load times and overall user
                                                experience. The new design featured a clean, visually appealing layout
                                                that better showcased the café's unique ambiance and offerings. We also
                                                ensured that the site was mobile-friendly to cater to on-the-go users
                                                searching for local coffee spots.
                                            </p>
                                            <h5>Targeted SEO Campaign:</h5>
                                            <p>
                                                Our SEO strategy focused on enhancing The Spark’s online visibility
                                                through targeted keyword optimization and content strategies. We
                                                identified high-value local search terms such as “best coffee near me”
                                                and “top coffee shops in [City]” and optimized the site’s content
                                                accordingly. This included updating meta tags, improving on-page SEO
                                                elements, and creating engaging, keyword-rich content that resonated
                                                with local customers.
                                            </p>
                                            <h5>Local SEO Optimization:</h5>
                                            <p>
                                                Given the nature of the business, local SEO was crucial. We optimized
                                                The Spark’s Google My Business profile, ensuring accurate and up-to-date
                                                information. This included adding compelling photos, updating business
                                                hours, and encouraging satisfied customers to leave positive reviews.
                                                This local focus aimed to increase the café's visibility in local search
                                                results and Google Maps.
                                            </p>
                                            <h5>Regular Progress Updates:</h5>
                                            <p>
                                                RankRunners provided The Spark with bi-weekly progress reports. These
                                                meetings included detailed analytics on website performance, keyword
                                                rankings, and traffic sources. We used these insights to refine our
                                                strategy continuously and ensure that The Spark remained on track to
                                                meet its digital marketing goals.
                                            </p>
                                            <h5>Social Media Integration:</h5>
                                            <p>
                                                To complement the website revamp and SEO efforts, we integrated social
                                                media into the strategy. We designed engaging social media campaigns
                                                that promoted The Spark’s offerings, events, and customer stories. This
                                                helped drive traffic to the website and further enhanced the café’s
                                                brand presence online.
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <Callback1 />
                <div>
                    <section className="project__details-area-one">
                        <div className="container">
                            <div className="project__details-wrap">
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <div className="project__details-inner">
                                                <div className="row align-items-center">
                                                    <div className="col-lg-12">
                                                        <h2>Key Achievements</h2>
                                                        <h5>Revamped Website:</h5>
                                                        <p>
                                                            The new site featured an updated design, improved load
                                                            times, and enhanced functionality, providing a better user
                                                            experience and aligning more closely with The Spark’s brand.
                                                        </p>
                                                        <h5>Improved Search Rankings:</h5>
                                                        <p>
                                                            The Spark’s website climbed from a #30 average search
                                                            position to the top 5 positions for key local search terms.
                                                        </p>
                                                        <h5>Enhanced Local Visibility:</h5>
                                                        <p>
                                                            The optimized Google My Business profile led to a 50%
                                                            increase in local search visibility and a 40% increase in
                                                            foot traffic from local customers.
                                                        </p>
                                                        <h5>Increased Engagement:</h5>
                                                        <p>
                                                            Social media integration and engaging content contributed to
                                                            a 60% increase in website traffic and a noticeable rise in
                                                            customer interactions and reviews.
                                                        </p>
                                                    </div>
                                                    <div className="col-lg-6 order-lg-1">
                                                        <div className="project__details-inner-img">
                                                            <img
                                                                src="/assets/img/case-study/the-spark-coffee-1.png"
                                                                alt=""
                                                            />
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-6">
                                                        <div className="project__details-inner-content">
                                                            <h2>The Results We Provided</h2>
                                                            <p>
                                                                The collaboration between The Spark and RankRunners
                                                                yielded impressive results. The revamped website,
                                                                combined with an effective SEO and local optimization
                                                                strategy, led to a substantial increase in online
                                                                visibility and customer engagement.
                                                            </p>

                                                            <div className="content-inner">
                                                                <h4>Before</h4>
                                                                <div className="row">
                                                                    <div className="col-md-6">
                                                                        <div className="case-study-cta-ba">
                                                                            <h3>Image Coming Soon</h3>
                                                                        </div>
                                                                    </div>
                                                                    <div className="col-md-6 about__list-box">
                                                                        <ul className="list-wrap">
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Outdated Website
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                #30 Avg. Search Position
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Low Local Visibility
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Minimal Social Media Engagement
                                                                            </li>
                                                                        </ul>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                            <div className="content-inner">
                                                                <h4>After</h4>
                                                                <div className="row">
                                                                    <div className="col-md-6">
                                                                        <div className="case-study-cta-ba">
                                                                            <video
                                                                                src="/assets/img/case-study/the-spark-coffee.webm"
                                                                                autoPlay
                                                                                muted
                                                                                loop
                                                                                alt=""
                                                                            />
                                                                        </div>
                                                                    </div>
                                                                    <div className="col-md-6 about__list-box">
                                                                        <ul className="list-wrap">
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Modernized Website
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Top 5 Avg. Search Position
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                +50% Local Visibility
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                +60% Website Traffic
                                                                            </li>
                                                                        </ul>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div className="col-lg-12 order-last">
                                                        <p>
                                                            The Spark’s revitalized online presence not only reflected
                                                            their brand’s unique charm but also significantly boosted
                                                            their search engine performance and local engagement. The
                                                            combined efforts of RankRunners in website design, SEO, and
                                                            local optimization resulted in a more vibrant and successful
                                                            digital footprint for The Spark, ultimately driving more
                                                            customers through their doors.
                                                        </p>

                                                        <p>
                                                            This case study demonstrates RankRunners’ commitment to
                                                            delivering tailored solutions that address specific client
                                                            challenges and achieve measurable improvements. The Spark’s
                                                            success story highlights our ability to transform digital
                                                            strategies into tangible business growth, fostering a
                                                            thriving online presence that complements their exceptional
                                                            in-person service.
                                                        </p>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
            </Layout>
        </>
    );
}
