import Layout from "@/components/layout/Layout";
import Callback1 from "@/components/sections/Callback1";
import CaseStudyDetail from "@/components/custom/CaseStudyDetail";

export const metadata = {
    title: "Case Study | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ProjectDetails() {
    let slug = "water-main-line-replacement";

    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Case Study: Water Main Line Replacement LLC">
                <div>
                    <section className="project__details-area">
                        <div className="container">
                            <div className="project__details-wrap">
                                <CaseStudyDetail slug={slug} />
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <h2>The Challenge We Faced</h2>
                                            <p>
                                                WaterMainLineReplacement.com had a great service but struggled to stand
                                                out online in a crowded local market. Their visibility was low, their
                                                website wasn’t optimized, and their local service ads were
                                                underperforming. Additionally, their Google Business Profile (GBP)
                                                wasn’t set up to attract or engage local customers effectively. Our
                                                mission at RankRunners was to boost their online presence and improve
                                                their search rankings so they could connect with more local customers
                                                who needed their services.
                                            </p>
                                            <h2>The Strategy We Applied</h2>
                                            <h5>Local Service Ad Campaign:</h5>
                                            <p>
                                                We designed and launched a focused local service ad campaign to enhance
                                                WaterMainLineReplacement.com’s presence in local searches. By zeroing in
                                                on specific areas and crafting compelling ad copy, we aimed to attract
                                                more potential customers and increase the effectiveness of their
                                                advertising spend.
                                            </p>
                                            <h5>Google Business Profile (GBP) Setup and Optimization:</h5>
                                            <p>
                                                We took charge of setting up and fine-tuning their Google Business
                                                Profile. This involved making sure all the information was accurate,
                                                adding high-quality photos, encouraging customer reviews, and using GBP
                                                features to boost their visibility and interaction with local searchers.
                                            </p>
                                            <h5>Site Development:</h5>
                                            <p>
                                                We overhauled their website to improve both its design and
                                                functionality. The new site was made more user-friendly and
                                                mobile-responsive, which helped with faster loading times and easier
                                                navigation. This not only enhanced the user experience but also
                                                supported better search engine optimization.
                                            </p>
                                            <h5>Improved Domain Authority and Ranking:</h5>
                                            <p>
                                                Our SEO strategy focused on increasing the site’s domain authority and
                                                search engine rankings. We worked on optimizing the site’s content with
                                                relevant keywords, improving technical aspects of the site, and building
                                                quality backlinks to boost their visibility and search performance.
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <Callback1 />
                <div>
                    <section className="project__details-area-one">
                        <div className="container">
                            <div className="project__details-wrap">
                                <div className="row">
                                    <div className="col-12">
                                        <div className="project__details-content">
                                            <div className="project__details-inner">
                                                <div className="row align-items-center">
                                                    <div className="col-lg-12">
                                                        <h2>The Results We Provided</h2>
                                                        <h5>Increased Local Visibility:</h5>
                                                        <p>
                                                            The local service ads brought a noticeable increase in local
                                                            inquiries and leads, helping WaterMainLineReplacement.com
                                                            reach more potential customers.
                                                        </p>
                                                        <h5>Enhanced GBP Performance:</h5>
                                                        <p>
                                                            With the optimized Google Business Profile, they saw a rise
                                                            in clicks, calls, and requests for directions, which
                                                            strengthened their local presence and engagement.
                                                        </p>
                                                        <h5>Website Improvement:</h5>
                                                        <p>
                                                            The redesigned website led to better user metrics, including
                                                            a reduction in bounce rates and longer session durations,
                                                            reflecting a more engaging and user-friendly site.
                                                        </p>
                                                        <h5>Better Search Rankings:</h5>
                                                        <p>
                                                            Our SEO efforts resulted in improved domain authority and
                                                            higher rankings for important search terms, driving more
                                                            organic traffic to the site.
                                                        </p>
                                                    </div>
                                                    {/* <div className="col-lg-6 order-lg-1">
                                                        <div className="project__details-inner-img">
                                                            <img
                                                                src="/assets/img/case-study/the-spark-coffee-1.png"
                                                                alt=""
                                                            />
                                                        </div>
                                                    </div> */}
                                                    {/* <div className="col-lg-6">
                                                        <div className="project__details-inner-content">
                                                            <h2>The Results We Provided</h2>
                                                            <p>
                                                                The collaboration between The Spark and RankRunners
                                                                yielded impressive results. The revamped website,
                                                                combined with an effective SEO and local optimization
                                                                strategy, led to a substantial increase in online
                                                                visibility and customer engagement.
                                                            </p>

                                                            <div className="content-inner">
                                                                <h4>Before</h4>
                                                                <div className="row">
                                                                    <div className="col-md-6">
                                                                        <div className="case-study-cta-ba">
                                                                            <h3>Image Coming Soon</h3>
                                                                        </div>
                                                                    </div>
                                                                    <div className="col-md-6 about__list-box">
                                                                        <ul className="list-wrap">
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Outdated Website
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                #30 Avg. Search Position
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Low Local Visibility
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Minimal Social Media Engagement
                                                                            </li>
                                                                        </ul>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                            <div className="content-inner">
                                                                <h4>After</h4>
                                                                <div className="row">
                                                                    <div className="col-md-6">
                                                                        <div className="case-study-cta-ba">
                                                                            <video
                                                                                src="/assets/img/case-study/the-spark-coffee.webm"
                                                                                autoPlay
                                                                                muted
                                                                                loop
                                                                                alt=""
                                                                            />
                                                                        </div>
                                                                    </div>
                                                                    <div className="col-md-6 about__list-box">
                                                                        <ul className="list-wrap">
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Modernized Website
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                Top 5 Avg. Search Position
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                +50% Local Visibility
                                                                            </li>
                                                                            <li>
                                                                                <i className="flaticon-arrow-button" />
                                                                                +60% Website Traffic
                                                                            </li>
                                                                        </ul>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div> */}
                                                    <div className="col-lg-12 order-last">
                                                        <p>
                                                            In short, RankRunners’ efforts helped
                                                            WaterMainLineReplacement.com enhance their online
                                                            visibility, attract more local customers, and improve their
                                                            overall digital presence.
                                                        </p>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
            </Layout>
        </>
    );
}
