import Layout from "@/components/layout/Layout";
import BrandActiveSlider from "@/components/slider/BrandActiveSlider";
import Link from "next/link";

export const metadata = {
    title: "Service Details | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ServicesDetails3() {
    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Services We Provide">
                <div>
                    <section className="services__details-area">
                        <div className="container">
                            <div className="services__details-wrap">
                                <div className="row">
                                    <div className="col-70 order-0 order-lg-2">
                                        <div className="services__details-content services__details-content-two">
                                            <h2 className="title">Ad Campaign Management</h2>
                                            <p>
                                                Launching and testing cost-effective ad campaigns on platforms like
                                                Google, Facebook, and X on a consistent basis can be tricky and
                                                time-consuming for those that don’t specialize in it. Many businesses
                                                struggle with crafting ads that resonate with their viewers, targeting
                                                the right audience, and managing their ad spend effectively. In fact,
                                                there are certifications for this skill set because of how complicated
                                                it can be. At RankRunners, our Google-Certified Account Specialists
                                                streamline this process by getting behind the wheel of your ad
                                                campaigns. Our expert team develops and manages targeted,
                                                high-performing ad campaigns that maximize your incoming leads and drive
                                                your company’s revenue upwards.
                                            </p>
                                            <div className="services__details-thumb">
                                                <img src="/assets/img/custom/service-02-01.png" alt="" />
                                            </div>
                                            <div className="services__details-inner-three">
                                                <h3>Benefits:</h3>
                                                <ul>
                                                    <li>
                                                        <strong>Strategic Ad Placement</strong>: We design and implement
                                                        targeted ad campaigns across multiple platforms to ensure your
                                                        ads reach the right audience at the right time.
                                                    </li>
                                                    <li>
                                                        <strong>Optimized Spend</strong>: Our data-driven approach
                                                        ensures your advertising budget is spent efficiently, focusing
                                                        on high-impact opportunities to generate the best results.
                                                    </li>
                                                    <li>
                                                        <strong>Creative Excellence</strong>: From eye-catching visuals
                                                        to compelling copy, our team creates ads that capture attention
                                                        and drive engagement.
                                                    </li>
                                                    <li>
                                                        <strong>Real-Time Analytics</strong>: We provide ongoing
                                                        performance tracking and insights, allowing for timely
                                                        adjustments and ensuring your campaigns stay on track.
                                                    </li>
                                                    <li>
                                                        <strong>Expert Management</strong>: Benefit from the expertise
                                                        of our dedicated ad managers who handle everything from strategy
                                                        and design to execution and reporting.
                                                    </li>
                                                </ul>
                                            </div>
                                            <div className="services__details-inner-two services__details-inner-four">
                                                <div className="gutter-24">
                                                    <div className="col-48">
                                                        <div className="services__details-inner-img float-img">
                                                            <img src="/assets/img/custom/service-02-02.png" alt="" />
                                                        </div>
                                                    </div>
                                                    <div className="col-52">
                                                        <div className="services__details-inner-content-two">
                                                            <h3>Services:</h3>
                                                            <ul>
                                                                <li>
                                                                    <strong>Campaign Strategy Development</strong>:
                                                                    Crafting a comprehensive strategy tailored to your
                                                                    business goals and target audience, ensuring
                                                                    alignment with your overall marketing objectives.
                                                                </li>
                                                                <li>
                                                                    <strong>Ad Creation and Design</strong>: Designing
                                                                    visually appealing and persuasive ads that stand out
                                                                    and resonate with your target market.
                                                                </li>
                                                                <li>
                                                                    <strong>Target Audience Research</strong>:
                                                                    Identifying and segmenting your ideal audience to
                                                                    ensure your ads reach those most likely to convert.
                                                                </li>
                                                                <li>
                                                                    <strong>Platform Management</strong>: Handling all
                                                                    aspects of your ad placements on platforms like
                                                                    Google Ads, Facebook, Instagram, and more.
                                                                </li>
                                                                <li>
                                                                    <strong>
                                                                        Performance Tracking and Optimization
                                                                    </strong>
                                                                    : Monitoring ad performance in real-time and making
                                                                    data-driven adjustments to improve results and ROI.
                                                                </li>
                                                                <li>
                                                                    <strong>Reporting and Insights</strong>: Providing
                                                                    detailed reports and actionable insights to measure
                                                                    the success of your campaigns and inform future
                                                                    strategies.
                                                                </li>
                                                            </ul>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <p>
                                                <strong>
                                                    The setup of an ad campaign typically takes 2 to 4 weeks, depending
                                                    on the complexity of the campaign and the platforms involved.
                                                    Ongoing management and optimization are continuous, with regular
                                                    updates and performance reviews provided on a monthly basis.
                                                </strong>
                                            </p>
                                            <div className="all_services__area-six-two">
                                                <div className="container">
                                                    <h3>Ready to “Run-Up” your advertising game?</h3>
                                                    <Link href="/schedule" className="btn">
                                                        Start Your Campaign Today!
                                                    </Link>
                                                </div>
                                            </div>
                                            <p>Have questions or need more details? Contact us today:</p>
                                            <div className="contact__info mb-50">
                                                <ul className="list-wrap">
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-phone-call" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Phone</h4>
                                                            <Link href="tel:+14702604117">(470) 260-4117</Link>
                                                        </div>
                                                    </li>
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-mail" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Email</h4>
                                                            <Link href="mailto:support@rankrunners.net">
                                                                support@rankrunners.net
                                                            </Link>
                                                        </div>
                                                    </li>
                                                </ul>
                                            </div>
                                            <h4 className="title-center">
                                                Let RankRunners drive your business growth with expertly managed ad
                                                campaigns!
                                            </h4>
                                        </div>
                                    </div>
                                    <div className="col-30">
                                        <aside className="services__sidebar">
                                            <div className="sidebar__widget">
                                                <div className="services-sidebar">
                                                    <ul className="list-wrap">
                                                        <li>
                                                            <Link href="/services/search-engine-optimization">
                                                                Search Engine Optimization
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link
                                                                href="/services/ad-campaign-management"
                                                                className="active"
                                                            >
                                                                Ad Campaign Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cloud-computing">
                                                                Cloud Computing <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/lead-generation">
                                                                Lead Generation <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/web-development">
                                                                Web Development/Design
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/social-media-management">
                                                                Social Media Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/performance-monitoring">
                                                                Performance Monitoring
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cyber-security">
                                                                Cyber Security <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/website-maintenance">
                                                                Website Maintenance
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                    </ul>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">SEO Checker</h4>
                                                <div className="sidebar__brochure sidebar__brochure-two">
                                                    <p>Check your website's SEO performance.</p>
                                                    <Link href="/#seocheck">SEO Checker</Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-two">
                                                <div
                                                    className="sidebar__contact sidebar__contact-two"
                                                    data-background="/assets/img/services/sidebar_contact_bg.jpg"
                                                >
                                                    <h2 className="title">
                                                        Contact Us Any Time For Immediate Support!
                                                    </h2>
                                                    <Link href="tel:+14702604117" className="btn">
                                                        <i className="flaticon-phone-call" />
                                                        (470) 260-4117
                                                    </Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">Send Us a Message</h4>
                                                <div className="sidebar__form">
                                                    <form action="#">
                                                        <div className="form-grp">
                                                            <input type="text" name="name" placeholder="Your Name" />
                                                        </div>
                                                        <div className="form-grp">
                                                            <input
                                                                type="text"
                                                                name="phone"
                                                                placeholder="Phone Number"
                                                            />
                                                        </div>
                                                        <div className="form-grp">
                                                            <textarea name="message" placeholder="Type Your Message" />
                                                        </div>
                                                        <button type="submit" className="btn btn-two">
                                                            Send Message
                                                        </button>
                                                    </form>
                                                </div>
                                            </div>
                                        </aside>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <div className="brand-area">
                    <div className="container">
                        <h4 className="brand__content">Trusted by Numerous Companies, Worldwide</h4>
                        <div className="swiper-container brand-active">
                            <BrandActiveSlider />
                        </div>
                    </div>
                </div>
            </Layout>
        </>
    );
}
