import Layout from "@/components/layout/Layout";
import BrandActiveSlider from "@/components/slider/BrandActiveSlider";
import Link from "next/link";

export const metadata = {
    title: "Service Details | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ServicesDetails3() {
    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Services We Provide">
                <div>
                    <section className="services__details-area">
                        <div className="container">
                            <div className="services__details-wrap">
                                <div className="row">
                                    <div className="col-70 order-0 order-lg-2">
                                        <div className="services__details-content services__details-content-two">
                                            <h2 className="title">Cloud Computing</h2>
                                            <p>
                                                Managing cloud-based IT infrastructure can be complex and costly, often
                                                requiring significant investments in hardware and maintenance. Many
                                                businesses face challenges with scalability, data storage, and
                                                operational efficiency. RankRunners offers a solution with our Cloud
                                                Computing services, providing a flexible, scalable, and cost-effective
                                                alternative to traditional IT setups. By leveraging the power of the
                                                cloud, we help your business optimize resources, enhance collaboration,
                                                and ensure data security, all while reducing operational overhead.
                                            </p>
                                            <div className="services__details-thumb">
                                                <img src="/assets/img/custom/service-03-01.png" alt="" />
                                            </div>
                                            <div className="services__details-inner-three">
                                                <h3>Benefits:</h3>
                                                <ul>
                                                    <li>
                                                        <strong>Scalability</strong>: Easily scale your computing
                                                        resources up or down based on your business needs, ensuring you
                                                        only pay for what you use.
                                                    </li>
                                                    <li>
                                                        <strong>Cost Efficiency</strong>: Reduce capital expenditures on
                                                        physical hardware and lower IT costs with our pay-as-you-go
                                                        cloud solutions.
                                                    </li>
                                                    <li>
                                                        <strong>Enhanced Collaboration</strong>: Enable seamless access
                                                        to data and applications from anywhere, improving team
                                                        collaboration and productivity.
                                                    </li>
                                                    <li>
                                                        <strong>Data Security</strong>: Benefit from advanced security
                                                        measures and compliance standards that protect your critical
                                                        data from threats and breaches.
                                                    </li>
                                                    <li>
                                                        <strong>Disaster Recovery</strong>: Ensure business continuity
                                                        with reliable backup and disaster recovery solutions that keep
                                                        your data safe and accessible.
                                                    </li>
                                                </ul>
                                            </div>
                                            <div className="services__details-inner-two services__details-inner-four">
                                                <div className="gutter-24">
                                                    <div className="col-48">
                                                        <div className="services__details-inner-img float-img">
                                                            <img src="/assets/img/custom/service-03-02.png" alt="" />
                                                        </div>
                                                    </div>
                                                    <div className="col-52">
                                                        <div className="services__details-inner-content-two">
                                                            <h3>Services:</h3>
                                                            <ul>
                                                                <li>
                                                                    <strong>Cloud Infrastructure Setup</strong>:
                                                                    Designing and deploying scalable cloud
                                                                    infrastructure tailored to your specific business
                                                                    requirements, ensuring optimal performance and
                                                                    reliability.
                                                                </li>
                                                                <li>
                                                                    <strong>Data Storage Solutions</strong>:
                                                                    Implementing secure and efficient cloud storage
                                                                    options that accommodate your data needs while
                                                                    ensuring quick access and backup.
                                                                </li>
                                                                <li>
                                                                    <strong>Cloud Migration</strong>: Facilitating a
                                                                    smooth transition of your existing systems and data
                                                                    to the cloud, minimizing downtime and disruption.
                                                                </li>
                                                                <li>
                                                                    <strong>Application Hosting</strong>: Hosting and
                                                                    managing your business applications in the cloud for
                                                                    improved accessibility and reduced maintenance.
                                                                </li>
                                                                <li>
                                                                    <strong>Security and Compliance</strong>: Providing
                                                                    robust security measures and compliance solutions to
                                                                    protect your data and meet industry regulations.
                                                                </li>
                                                                <li>
                                                                    <strong>Ongoing Support and Management</strong>:
                                                                    Offering continuous support and management services
                                                                    to keep your cloud environment running smoothly and
                                                                    efficiently.
                                                                </li>
                                                            </ul>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <p>
                                                <strong>
                                                    The initial setup and migration to a cloud environment typically
                                                    take 3 to 6 weeks, depending on the complexity of your existing
                                                    infrastructure and specific needs. Our ongoing support is
                                                    continuous, ensuring your cloud services remain optimized and
                                                    secure.
                                                </strong>
                                            </p>
                                            <div className="all_services__area-six-two">
                                                <div className="container">
                                                    <h3>
                                                        Efficiently scale your IT infrastructure with our innovative
                                                        cloud solutions!
                                                    </h3>
                                                    <Link href="/schedule" className="btn">
                                                        Get Started with Cloud Computing Today!
                                                    </Link>
                                                </div>
                                            </div>
                                            <p>Have questions or need more details? Contact us today:</p>
                                            <div className="contact__info mb-50">
                                                <ul className="list-wrap">
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-phone-call" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Phone</h4>
                                                            <Link href="tel:+14702604117">(470) 260-4117</Link>
                                                        </div>
                                                    </li>
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-mail" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Email</h4>
                                                            <Link href="mailto:support@rankrunners.net">
                                                                support@rankrunners.net
                                                            </Link>
                                                        </div>
                                                    </li>
                                                </ul>
                                            </div>
                                            <h4 className="title-center">
                                                Let RankRunners guide you to the future of business technology with our
                                                expert cloud computing services!
                                            </h4>
                                        </div>
                                    </div>
                                    <div className="col-30">
                                        <aside className="services__sidebar">
                                            <div className="sidebar__widget">
                                                <div className="services-sidebar">
                                                    <ul className="list-wrap">
                                                        <li>
                                                            <Link href="/services/search-engine-optimization">
                                                                Search Engine Optimization
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/ad-campaign-management">
                                                                Ad Campaign Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cloud-computing" className="active">
                                                                Cloud Computing <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/lead-generation">
                                                                Lead Generation <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/web-development">
                                                                Web Development/Design
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/social-media-management">
                                                                Social Media Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/performance-monitoring">
                                                                Performance Monitoring
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cyber-security">
                                                                Cyber Security <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/website-maintenance">
                                                                Website Maintenance
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                    </ul>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">SEO Checker</h4>
                                                <div className="sidebar__brochure sidebar__brochure-two">
                                                    <p>Check your website's SEO performance.</p>
                                                    <Link href="/#seocheck">SEO Checker</Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-two">
                                                <div
                                                    className="sidebar__contact sidebar__contact-two"
                                                    data-background="/assets/img/services/sidebar_contact_bg.jpg"
                                                >
                                                    <h2 className="title">
                                                        Contact Us Any Time For Immediate Support!
                                                    </h2>
                                                    <Link href="tel:+14702604117" className="btn">
                                                        <i className="flaticon-phone-call" />
                                                        (470) 260-4117
                                                    </Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">Send Us a Message</h4>
                                                <div className="sidebar__form">
                                                    <form action="#">
                                                        <div className="form-grp">
                                                            <input type="text" name="name" placeholder="Your Name" />
                                                        </div>
                                                        <div className="form-grp">
                                                            <input
                                                                type="text"
                                                                name="phone"
                                                                placeholder="Phone Number"
                                                            />
                                                        </div>
                                                        <div className="form-grp">
                                                            <textarea name="message" placeholder="Type Your Message" />
                                                        </div>
                                                        <button type="submit" className="btn btn-two">
                                                            Send Message
                                                        </button>
                                                    </form>
                                                </div>
                                            </div>
                                        </aside>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <div className="brand-area">
                    <div className="container">
                        <h4 className="brand__content">Trusted by Numerous Companies, Worldwide</h4>
                        <div className="swiper-container brand-active">
                            <BrandActiveSlider />
                        </div>
                    </div>
                </div>
            </Layout>
        </>
    );
}
