import Layout from "@/components/layout/Layout";
import BrandActiveSlider from "@/components/slider/BrandActiveSlider";
import Link from "next/link";

export const metadata = {
    title: "Service Details | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ServicesDetails3() {
    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Services We Provide">
                <div>
                    <section className="services__details-area">
                        <div className="container">
                            <div className="services__details-wrap">
                                <div className="row">
                                    <div className="col-70 order-0 order-lg-2">
                                        <div className="services__details-content services__details-content-two">
                                            <h2 className="title">Cyber Security</h2>
                                            <p>
                                                Cyber Security is an often overlooked facet of today’s business life, be
                                                it online or offline data. It mustn't be neglected whether wilfully so
                                                or by accident. Having a flourishing company often draws the focus
                                                towards the daily goings-on and making sure that revenue streams stay
                                                positive. We at RankRunners offer world-class security solutions so that
                                                your company does not have to worry about whether that one employee
                                                works on public wifi from time to time. Our experts will formulate an
                                                audit and make sure that any potential security breaches will stay just
                                                that. “Potential”.
                                            </p>
                                            <div className="services__details-thumb">
                                                <img src="/assets/img/custom/service-08-01.png" alt="" />
                                            </div>
                                            <div className="services__details-inner-three">
                                                <h3>Benefits:</h3>
                                                <ul>
                                                    <li>
                                                        <strong>Knowledge</strong>: Knowing where your company is
                                                        vulnerable is the first step to fixing these security issues.
                                                        Having your vulnerabilities clearly and expertly mapped out will
                                                        ensure that there are no interruptions in the daily workflow so
                                                        you can do what you do best!
                                                    </li>
                                                    <li>
                                                        <strong>
                                                            Formulating a plan for when the unthinkable happens
                                                        </strong>
                                                        : Having a plan for if and when a cyber security breach does
                                                        occur, knowing what to do is just as important doing your taxes.
                                                        This plan ensures that your company’s vital tasks can continue
                                                        to the fullest extent until the problem is solved.
                                                    </li>
                                                    <li>
                                                        <strong>Future breach prevention</strong>: Ensuring that you
                                                        have measures in place to prevent breaches is another incredibly
                                                        important part of your company being (mostly) safe from attacks.
                                                        for example:
                                                        <ol>
                                                            <li>
                                                                Ideally employees need to change their passwords often
                                                                (as annoying as it may be)
                                                            </li>
                                                            <li>
                                                                Utilizing Two-Factor Authentication, requiring employees
                                                                who have access to sensitive information to use 2FA
                                                                (Two-Factor Authentication) is a must!
                                                            </li>
                                                        </ol>
                                                        Now there are countless other measures that can be put in place
                                                        but they go past the scope of this page.
                                                    </li>
                                                    <li>
                                                        <strong>Higher client trust</strong>: If your client sees that
                                                        you have your affairs in order they are more likely to trust
                                                        your company with their valuable information.
                                                    </li>
                                                </ul>
                                            </div>
                                            <div className="services__details-inner-two services__details-inner-four">
                                                <div className="gutter-24">
                                                    <div className="col-48">
                                                        <div className="services__details-inner-img float-img">
                                                            <img src="/assets/img/custom/service-08-02.png" alt="" />
                                                        </div>
                                                    </div>
                                                    <div className="col-52">
                                                        <div className="services__details-inner-content-two">
                                                            <h3>Services:</h3>
                                                            <ul>
                                                                <li>
                                                                    <strong>Plan of action</strong>: Rankrunners will
                                                                    assess every facet of your company to meticulously
                                                                    craft a plan to ensure your company will not fall
                                                                    victim to a cyber attack.
                                                                </li>
                                                                <li>
                                                                    <strong>
                                                                        Continued monitoring of suspicious activity
                                                                    </strong>
                                                                    : Rankrunners will continuously monitor your
                                                                    company’s online security to ensure anything out of
                                                                    the ordinary is proofed and checked to make sure it
                                                                    is nothing malicious.
                                                                </li>
                                                                <li>
                                                                    <strong>Recurring Security checks</strong>:
                                                                    Rankrunners will perform recurring security checks
                                                                    to make sure your company is up to date with the
                                                                    latest globally recognized security standards.
                                                                </li>
                                                            </ul>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <p>
                                                <strong>
                                                    Initial setup and an extended audit of your company typically takes
                                                    2 to 4 weeks, depending on the complexity of your needs and existing
                                                    systems. Ongoing security checks and monitoring is continuous, with
                                                    as-needed updates and solutions provided to keep you safe and
                                                    secure.
                                                </strong>
                                            </p>
                                            <div className="all_services__area-six-two">
                                                <div className="container">
                                                    <h3>
                                                        Get on top of your company’s security today! Don’t become a
                                                        Cyber-attack victim!
                                                    </h3>
                                                    <Link href="/schedule" className="btn">
                                                        Start Getting Secure Today!
                                                    </Link>
                                                </div>
                                            </div>
                                            <p>Have questions or need more details? Contact us today:</p>
                                            <div className="contact__info mb-50">
                                                <ul className="list-wrap">
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-phone-call" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Phone</h4>
                                                            <Link href="tel:+14702604117">(470) 260-4117</Link>
                                                        </div>
                                                    </li>
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-mail" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Email</h4>
                                                            <Link href="mailto:support@rankrunners.net">
                                                                support@rankrunners.net
                                                            </Link>
                                                        </div>
                                                    </li>
                                                </ul>
                                            </div>
                                            <h4 className="title-center">
                                                Let RankRunners protect your company with our cyber-security experts so
                                                you can keep your company ahead of the competition!
                                            </h4>
                                        </div>
                                    </div>
                                    <div className="col-30">
                                        <aside className="services__sidebar">
                                            <div className="sidebar__widget">
                                                <div className="services-sidebar">
                                                    <ul className="list-wrap">
                                                        <li>
                                                            <Link href="/services/search-engine-optimization">
                                                                Search Engine Optimization
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/ad-campaign-management">
                                                                Ad Campaign Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cloud-computing">
                                                                Cloud Computing <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/lead-generation">
                                                                Lead Generation <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/web-development">
                                                                Web Development/Design
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/social-media-management">
                                                                Social Media Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/performance-monitoring">
                                                                Performance Monitoring
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cyber-security" className="active">
                                                                Cyber Security <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/website-maintenance">
                                                                Website Maintenance
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                    </ul>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">SEO Checker</h4>
                                                <div className="sidebar__brochure sidebar__brochure-two">
                                                    <p>Check your website's SEO performance.</p>
                                                    <Link href="/#seocheck">SEO Checker</Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-two">
                                                <div
                                                    className="sidebar__contact sidebar__contact-two"
                                                    data-background="/assets/img/services/sidebar_contact_bg.jpg"
                                                >
                                                    <h2 className="title">
                                                        Contact Us Any Time For Immediate Support!
                                                    </h2>
                                                    <Link href="tel:+14702604117" className="btn">
                                                        <i className="flaticon-phone-call" />
                                                        (470) 260-4117
                                                    </Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">Send Us a Message</h4>
                                                <div className="sidebar__form">
                                                    <form action="#">
                                                        <div className="form-grp">
                                                            <input type="text" name="name" placeholder="Your Name" />
                                                        </div>
                                                        <div className="form-grp">
                                                            <input
                                                                type="text"
                                                                name="phone"
                                                                placeholder="Phone Number"
                                                            />
                                                        </div>
                                                        <div className="form-grp">
                                                            <textarea name="message" placeholder="Type Your Message" />
                                                        </div>
                                                        <button type="submit" className="btn btn-two">
                                                            Send Message
                                                        </button>
                                                    </form>
                                                </div>
                                            </div>
                                        </aside>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <div className="brand-area">
                    <div className="container">
                        <h4 className="brand__content">Trusted by Numerous Companies, Worldwide</h4>
                        <div className="swiper-container brand-active">
                            <BrandActiveSlider />
                        </div>
                    </div>
                </div>
            </Layout>
        </>
    );
}
