import Layout from "@/components/layout/Layout";
import BrandActiveSlider from "@/components/slider/BrandActiveSlider";
import Link from "next/link";

export const metadata = {
    title: "Service Details | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ServicesDetails3() {
    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Services We Provide">
                <div>
                    <section className="services__details-area">
                        <div className="container">
                            <div className="services__details-wrap">
                                <div className="row">
                                    <div className="col-70 order-0 order-lg-2">
                                        <div className="services__details-content services__details-content-two">
                                            <h2 className="title">Lead Generation</h2>
                                            <p>
                                                Finding and converting high-quality leads on a consistent basis is often
                                                the largest hurdle to leap for many businesses. Without a steady stream
                                                of qualified prospects, growing your customer base and boosting sales
                                                becomes a daunting task. At RankRunners, our Lead Generation services
                                                tackle this problem head-on. We use the latest, most advanced techniques
                                                and strategies to attract, engage, and convert leads that are most
                                                likely to benefit from your products or services, ensuring a steady flow
                                                of potential customers and driving your business growth.
                                            </p>
                                            <div className="services__details-thumb">
                                                <img src="/assets/img/custom/service-04-01.png" alt="" />
                                            </div>
                                            <div className="services__details-inner-three">
                                                <h3>Benefits:</h3>
                                                <ul>
                                                    <li>
                                                        <strong>Qualified Leads</strong>: We focus on generating
                                                        high-quality leads that are genuinely interested in what you
                                                        offer, improving your chances of conversion and sales.
                                                    </li>
                                                    <li>
                                                        <strong>Customized Campaigns</strong>: Tailored lead generation
                                                        strategies that align with your specific business goals and
                                                        target audience, ensuring maximum effectiveness.
                                                    </li>
                                                    <li>
                                                        <strong>Increased Efficiency</strong>: Streamline your sales
                                                        process with a consistent influx of leads, allowing your sales
                                                        team to focus on closing deals rather than finding prospects.
                                                    </li>
                                                    <li>
                                                        <strong>Data-Driven Insights</strong>: Benefit from our detailed
                                                        analytics and reports that provide insights into lead quality,
                                                        campaign performance, and areas for improvement.
                                                    </li>
                                                    <li>
                                                        <strong>Cost-Effective</strong>: Optimize your lead generation
                                                        spend with strategies designed to deliver the best return on
                                                        investment and reduce wasted efforts.
                                                    </li>
                                                </ul>
                                            </div>
                                            <div className="services__details-inner-two services__details-inner-four">
                                                <div className="gutter-24">
                                                    <div className="col-48">
                                                        <div className="services__details-inner-img float-img">
                                                            <img src="/assets/img/custom/service-04-02.png" alt="" />
                                                        </div>
                                                    </div>
                                                    <div className="col-52">
                                                        <div className="services__details-inner-content-two">
                                                            <h3>Services:</h3>
                                                            <ul>
                                                                <li>
                                                                    <strong>Lead Generation Strategy</strong>:
                                                                    Developing a comprehensive strategy that outlines
                                                                    the best tactics and channels to reach your target
                                                                    audience effectively.
                                                                </li>
                                                                <li>
                                                                    <strong>Content Marketing</strong>: Creating
                                                                    engaging and valuable content that attracts and
                                                                    nurtures leads, positioning your brand as an
                                                                    industry authority.
                                                                </li>
                                                                <li>
                                                                    <strong>Email Campaigns</strong>: Designing and
                                                                    executing targeted email campaigns that capture
                                                                    interest and drive engagement from potential leads.
                                                                </li>
                                                                <li>
                                                                    <strong>Social Media Lead Generation</strong>:
                                                                    Utilizing social media platforms to connect with
                                                                    prospects and generate leads through organic and
                                                                    paid strategies.
                                                                </li>
                                                                <li>
                                                                    <strong>Landing Page Optimization</strong>: Crafting
                                                                    and optimizing high-converting landing pages
                                                                    designed to capture lead information and drive
                                                                    conversions.
                                                                </li>
                                                                <li>
                                                                    <strong>Lead Nurturing</strong>: Implementing
                                                                    systems and tactics to engage and nurture leads
                                                                    through the sales funnel, increasing the likelihood
                                                                    of conversion.
                                                                </li>
                                                            </ul>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <p>
                                                <strong>
                                                    Initial lead generation setup and campaign launch typically take 4
                                                    to 6 weeks, depending on the complexity of the strategy and the
                                                    channels involved. Ongoing lead generation efforts are continuous,
                                                    with regular updates and performance reviews provided on a monthly
                                                    basis.
                                                </strong>
                                            </p>
                                            <div className="all_services__area-six-two">
                                                <div className="container">
                                                    <h3>
                                                        Ready to have high-quality leads “Running” towards your
                                                        business?
                                                    </h3>
                                                    <Link href="/schedule" className="btn">
                                                        Start Generating Leads Today!
                                                    </Link>
                                                </div>
                                            </div>
                                            <p>Have questions or need more details? Contact us today:</p>
                                            <div className="contact__info mb-50">
                                                <ul className="list-wrap">
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-phone-call" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Phone</h4>
                                                            <Link href="tel:+14702604117">(470) 260-4117</Link>
                                                        </div>
                                                    </li>
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-mail" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Email</h4>
                                                            <Link href="mailto:support@rankrunners.net">
                                                                support@rankrunners.net
                                                            </Link>
                                                        </div>
                                                    </li>
                                                </ul>
                                            </div>
                                            <h4 className="title-center">
                                                Let RankRunners help you turn prospects into loyal customers with our
                                                expert lead generation services!
                                            </h4>
                                        </div>
                                    </div>
                                    <div className="col-30">
                                        <aside className="services__sidebar">
                                            <div className="sidebar__widget">
                                                <div className="services-sidebar">
                                                    <ul className="list-wrap">
                                                        <li>
                                                            <Link href="/services/search-engine-optimization">
                                                                Search Engine Optimization
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/ad-campaign-management">
                                                                Ad Campaign Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cloud-computing">
                                                                Cloud Computing <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/lead-generation" className="active">
                                                                Lead Generation <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/web-development">
                                                                Web Development/Design
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/social-media-management">
                                                                Social Media Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/performance-monitoring">
                                                                Performance Monitoring
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cyber-security">
                                                                Cyber Security <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/website-maintenance">
                                                                Website Maintenance
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                    </ul>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">SEO Checker</h4>
                                                <div className="sidebar__brochure sidebar__brochure-two">
                                                    <p>Check your website's SEO performance.</p>
                                                    <Link href="/#seocheck">SEO Checker</Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-two">
                                                <div
                                                    className="sidebar__contact sidebar__contact-two"
                                                    data-background="/assets/img/services/sidebar_contact_bg.jpg"
                                                >
                                                    <h2 className="title">
                                                        Contact Us Any Time For Immediate Support!
                                                    </h2>
                                                    <Link href="tel:+14702604117" className="btn">
                                                        <i className="flaticon-phone-call" />
                                                        (470) 260-4117
                                                    </Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">Send Us a Message</h4>
                                                <div className="sidebar__form">
                                                    <form action="#">
                                                        <div className="form-grp">
                                                            <input type="text" name="name" placeholder="Your Name" />
                                                        </div>
                                                        <div className="form-grp">
                                                            <input
                                                                type="text"
                                                                name="phone"
                                                                placeholder="Phone Number"
                                                            />
                                                        </div>
                                                        <div className="form-grp">
                                                            <textarea name="message" placeholder="Type Your Message" />
                                                        </div>
                                                        <button type="submit" className="btn btn-two">
                                                            Send Message
                                                        </button>
                                                    </form>
                                                </div>
                                            </div>
                                        </aside>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <div className="brand-area">
                    <div className="container">
                        <h4 className="brand__content">Trusted by Numerous Companies, Worldwide</h4>
                        <div className="swiper-container brand-active">
                            <BrandActiveSlider />
                        </div>
                    </div>
                </div>
            </Layout>
        </>
    );
}
