import Layout from "@/components/layout/Layout";
import BrandActiveSlider from "@/components/slider/BrandActiveSlider";
import Link from "next/link";

export const metadata = {
    title: "Service Details | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ServicesDetails3() {
    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Services We Provide">
                <div>
                    <section className="services__details-area">
                        <div className="container">
                            <div className="services__details-wrap">
                                <div className="row">
                                    <div className="col-70 order-0 order-lg-2">
                                        <div className="services__details-content services__details-content-two">
                                            <h2 className="title">Performance Monitoring</h2>
                                            <p>
                                                When you invest into digital marketing, you’ll want to understand and
                                                keep tabs on how your investments are performing. Many businesses
                                                struggle with tracking and interpreting data across various channels in
                                                a digestible fashion, which can lead to missed opportunities and wasted
                                                resources. RankRunners addresses these challenges with our Performance
                                                Monitoring services. We provide detailed insights into your website’s
                                                technical performance, lead generation/conversion metrics, and social
                                                media statistics, all visualized in a customized, easy-to-understand
                                                presentation tailored specifically for your ease of processing. Our goal
                                                is to confirm that your marketing efforts are driving profit and to help
                                                you make data-driven decisions for continued success.
                                            </p>
                                            <div className="services__details-thumb">
                                                <img src="/assets/img/custom/service-07-01.png" alt="" />
                                            </div>
                                            <div className="services__details-inner-three">
                                                <h3>Benefits:</h3>
                                                <ul>
                                                    <li>
                                                        <strong>Holistic View</strong>: Gain a comprehensive overview of
                                                        your marketing performance across all channels, including
                                                        technical website performance, lead generation, and social
                                                        media.
                                                    </li>
                                                    <li>
                                                        <strong>Data Visualization</strong>: Receive clear, visual
                                                        reports that make complex data easy to understand and
                                                        actionable, allowing you to see exactly how your investments are
                                                        performing.
                                                    </li>
                                                    <li>
                                                        <strong>Informed Decisions</strong>: Utilize detailed
                                                        performance insights to make strategic adjustments and optimize
                                                        your marketing efforts for better results and higher ROI.
                                                    </li>
                                                    <li>
                                                        <strong>Real-Time Monitoring</strong>: Track key metrics and
                                                        performance indicators in real-time, enabling you to respond
                                                        swiftly to changes and opportunities.
                                                    </li>
                                                    <li>
                                                        <strong>Profit Confirmation</strong>: Validate that your
                                                        marketing investments are delivering the desired outcomes,
                                                        ensuring that every dollar spent contributes to your business’s
                                                        success.
                                                    </li>
                                                </ul>
                                            </div>
                                            <div className="services__details-inner-two services__details-inner-four">
                                                <div className="gutter-24">
                                                    <div className="col-48">
                                                        <div className="services__details-inner-img float-img">
                                                            <img src="/assets/img/custom/service-07-02.png" alt="" />
                                                        </div>
                                                    </div>
                                                    <div className="col-52">
                                                        <div className="services__details-inner-content-two">
                                                            <h3>Services:</h3>
                                                            <ul>
                                                                <li>
                                                                    <strong>
                                                                        Technical Website Performance Monitoring
                                                                    </strong>
                                                                    : Regularly assessing your website’s speed, uptime,
                                                                    and overall functionality to ensure a seamless user
                                                                    experience and identify areas for improvement.
                                                                </li>
                                                                <li>
                                                                    <strong>
                                                                        Lead Generation and Conversion Tracking
                                                                    </strong>
                                                                    : Measuring the effectiveness of your lead
                                                                    generation strategies and conversion rates to
                                                                    optimize your sales funnel and maximize ROI.
                                                                </li>
                                                                <li>
                                                                    <strong>Social Media Performance Analysis</strong>:
                                                                    Tracking engagement, reach, and other key metrics on
                                                                    social media platforms to evaluate the impact of
                                                                    your social media efforts.
                                                                </li>
                                                                <li>
                                                                    <strong>Custom Reporting</strong>: Providing
                                                                    tailored, visual reports that summarize key
                                                                    performance data and highlight trends, enabling you
                                                                    to easily interpret results and make informed
                                                                    decisions.
                                                                </li>
                                                                <li>
                                                                    <strong>
                                                                        Performance Optimization Recommendations
                                                                    </strong>
                                                                    : Offering actionable insights and recommendations
                                                                    based on performance data to help you refine your
                                                                    marketing strategies and improve results.
                                                                </li>
                                                            </ul>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <p>
                                                <strong>
                                                    Initial setup and implementation of performance monitoring tools
                                                    typically take 2 to 4 weeks, depending on the complexity of your
                                                    needs and existing systems. Ongoing monitoring and reporting are
                                                    continuous, with monthly updates and performance reviews provided to
                                                    keep you informed and agile.
                                                </strong>
                                            </p>
                                            <div className="all_services__area-six-two">
                                                <div className="container">
                                                    <h3>Ensure your marketing investments are paying off!</h3>
                                                    <Link href="/schedule" className="btn">
                                                        Start Monitoring Your Performance Today!
                                                    </Link>
                                                </div>
                                            </div>
                                            <p>Have questions or need more details? Contact us today:</p>
                                            <div className="contact__info mb-50">
                                                <ul className="list-wrap">
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-phone-call" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Phone</h4>
                                                            <Link href="tel:+14702604117">(470) 260-4117</Link>
                                                        </div>
                                                    </li>
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-mail" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Email</h4>
                                                            <Link href="mailto:support@rankrunners.net">
                                                                support@rankrunners.net
                                                            </Link>
                                                        </div>
                                                    </li>
                                                </ul>
                                            </div>
                                            <h4 className="title-center">
                                                Let RankRunners create the insights you need to drive your marketing
                                                success with our expert performance monitoring services!
                                            </h4>
                                        </div>
                                    </div>
                                    <div className="col-30">
                                        <aside className="services__sidebar">
                                            <div className="sidebar__widget">
                                                <div className="services-sidebar">
                                                    <ul className="list-wrap">
                                                        <li>
                                                            <Link href="/services/search-engine-optimization">
                                                                Search Engine Optimization
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/ad-campaign-management">
                                                                Ad Campaign Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cloud-computing">
                                                                Cloud Computing <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/lead-generation">
                                                                Lead Generation <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/web-development">
                                                                Web Development/Design
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/social-media-management">
                                                                Social Media Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link
                                                                href="/services/performance-monitoring"
                                                                className="active"
                                                            >
                                                                Performance Monitoring
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cyber-security">
                                                                Cyber Security <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/website-maintenance">
                                                                Website Maintenance
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                    </ul>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">SEO Checker</h4>
                                                <div className="sidebar__brochure sidebar__brochure-two">
                                                    <p>Check your website's SEO performance.</p>
                                                    <Link href="/#seocheck">SEO Checker</Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-two">
                                                <div
                                                    className="sidebar__contact sidebar__contact-two"
                                                    data-background="/assets/img/services/sidebar_contact_bg.jpg"
                                                >
                                                    <h2 className="title">
                                                        Contact Us Any Time For Immediate Support!
                                                    </h2>
                                                    <Link href="tel:+14702604117" className="btn">
                                                        <i className="flaticon-phone-call" />
                                                        (470) 260-4117
                                                    </Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">Send Us a Message</h4>
                                                <div className="sidebar__form">
                                                    <form action="#">
                                                        <div className="form-grp">
                                                            <input type="text" name="name" placeholder="Your Name" />
                                                        </div>
                                                        <div className="form-grp">
                                                            <input
                                                                type="text"
                                                                name="phone"
                                                                placeholder="Phone Number"
                                                            />
                                                        </div>
                                                        <div className="form-grp">
                                                            <textarea name="message" placeholder="Type Your Message" />
                                                        </div>
                                                        <button type="submit" className="btn btn-two">
                                                            Send Message
                                                        </button>
                                                    </form>
                                                </div>
                                            </div>
                                        </aside>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <div className="brand-area">
                    <div className="container">
                        <h4 className="brand__content">Trusted by Numerous Companies, Worldwide</h4>
                        <div className="swiper-container brand-active">
                            <BrandActiveSlider />
                        </div>
                    </div>
                </div>
            </Layout>
        </>
    );
}
