import Layout from "@/components/layout/Layout";
import BrandActiveSlider from "@/components/slider/BrandActiveSlider";
import Link from "next/link";

export const metadata = {
    title: "Service Details | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ServicesDetails3() {
    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Services We Provide">
                <div>
                    <section className="services__details-area">
                        <div className="container">
                            <div className="services__details-wrap">
                                <div className="row">
                                    <div className="col-70 order-0 order-lg-2">
                                        <div className="services__details-content services__details-content-two">
                                            <h2 className="title">Search Engine Optimization</h2>
                                            <p>
                                                Businesses utilizing an online presence are becoming more saturated by
                                                the day. The competition keeps increasing, and it is projected to
                                                continue to increase at an exponential rate, as the physical world
                                                collectively and gradually transitions onto the digital one. Because of
                                                this fact, simply having a visually pleasing website isn’t enough to
                                                rank your website at the top of Google’s search results. If your website
                                                isn’t optimized for search engines, it’s like having a beautifully
                                                designed store that no one knows about. Poor SEO means low visibility,
                                                less traffic, and missed opportunities. At RankRunners, we have years of
                                                successful and proven SEO experience under our belt that will turn your
                                                website into a powerful magnet for search engines and users alike. Our
                                                SEO Optimization service improves your search engine rankings, increases
                                                your domain authority, and drives targeted traffic to your site,
                                                ensuring your online presence is both impactful and effective.
                                            </p>
                                            <div className="services__details-thumb">
                                                <img src="/assets/img/custom/service-01-01.png" alt="" />
                                            </div>
                                            <div className="services__details-inner-three">
                                                <h3>Benefits:</h3>
                                                <ul>
                                                    <li>
                                                        <strong>Increased Visibility</strong>: Our expert strategies
                                                        boost your website’s ranking on search engines, making it easier
                                                        for potential customers to find you.
                                                    </li>
                                                    <li>
                                                        <strong>Targeted Traffic</strong>: We attract visitors who are
                                                        actively searching for your products or services, leading to
                                                        higher engagement and conversion rates.
                                                    </li>
                                                    <li>
                                                        <strong>Customized Strategy</strong>: Our SEO plans are tailored
                                                        to your specific industry, audience, and goals, ensuring the
                                                        best results for your business.
                                                    </li>
                                                    <li>
                                                        <strong>Comprehensive Analysis</strong>: We provide in-depth
                                                        performance reports and analytics, so you can track the progress
                                                        and success of your SEO efforts.
                                                    </li>
                                                    <li>
                                                        <strong>Long-Term Results</strong>: Our SEO optimization focuses
                                                        on sustainable growth, helping you maintain and build upon your
                                                        search engine ranking over time.
                                                    </li>
                                                </ul>
                                            </div>
                                            <div className="services__details-inner-two services__details-inner-four">
                                                <div className="gutter-24">
                                                    <div className="col-48">
                                                        <div className="services__details-inner-img float-img">
                                                            <img src="/assets/img/custom/service-01-02.png" alt="" />
                                                        </div>
                                                    </div>
                                                    <div className="col-52">
                                                        <div className="services__details-inner-content-two">
                                                            <h3>Services:</h3>
                                                            <ul>
                                                                <li>
                                                                    <strong>Keyword Research</strong>: Identifying
                                                                    high-value keywords that attract your target
                                                                    audience and drive qualified traffic to your site.
                                                                </li>
                                                                <li>
                                                                    <strong>On-Page Optimization</strong>: Enhancing
                                                                    individual web pages to improve search engine
                                                                    rankings and user experience, including meta tags,
                                                                    headers, and content.
                                                                </li>
                                                                <li>
                                                                    <strong>Technical SEO</strong>: Addressing technical
                                                                    aspects of your website, such as site speed, mobile
                                                                    responsiveness, and crawlability, to ensure it meets
                                                                    search engine standards.
                                                                </li>
                                                                <li>
                                                                    <strong>Content Creation</strong>: Developing
                                                                    high-quality, relevant content (Blogs, Services,
                                                                    Front Page, About Us, etc.) that engages visitors
                                                                    and improves your site’s authority and ranking
                                                                    according to certain keywords.
                                                                </li>
                                                                <li>
                                                                    <strong>Link Building</strong>: Creating a strong
                                                                    backlink profile through ethical and effective
                                                                    strategies to boost your site’s credibility and
                                                                    search engine ranking.
                                                                </li>
                                                                <li>
                                                                    <strong>Performance Monitoring</strong>: Regularly
                                                                    analyzing and reporting on SEO performance to ensure
                                                                    ongoing optimization and improvement.
                                                                </li>
                                                            </ul>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <p>
                                                <strong>
                                                    SEO is an ongoing process with results typically becoming visible
                                                    within 3 to 6 months. Initial optimization can be completed within 4
                                                    to 6 weeks, depending on the complexity of your website and the
                                                    scope of the work.
                                                </strong>
                                            </p>
                                            <div className="all_services__area-six-two">
                                                <div className="container">
                                                    <h3>Ready to “Outrun” your competition?</h3>
                                                    <Link href="/schedule" className="btn">
                                                        Get Started Today!
                                                    </Link>
                                                </div>
                                            </div>
                                            <p>
                                                Have questions or ready to kick off your SEO journey? Reach out to us
                                                via:
                                            </p>
                                            <div className="contact__info mb-50">
                                                <ul className="list-wrap">
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-phone-call" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Phone</h4>
                                                            <Link href="tel:+14702604117">(470) 260-4117</Link>
                                                        </div>
                                                    </li>
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-mail" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Email</h4>
                                                            <Link href="mailto:support@rankrunners.net">
                                                                support@rankrunners.net
                                                            </Link>
                                                        </div>
                                                    </li>
                                                </ul>
                                            </div>
                                            <h4 className="title-center">
                                                We look forward to helping your business achieve greater online success!
                                            </h4>
                                        </div>
                                    </div>
                                    <div className="col-30">
                                        <aside className="services__sidebar">
                                            <div className="sidebar__widget">
                                                <div className="services-sidebar">
                                                    <ul className="list-wrap">
                                                        <li>
                                                            <Link
                                                                href="/services/search-engine-optimization"
                                                                className="active"
                                                            >
                                                                Search Engine Optimization
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/ad-campaign-management">
                                                                Ad Campaign Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cloud-computing">
                                                                Cloud Computing <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/lead-generation">
                                                                Lead Generation <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/web-development">
                                                                Web Development/Design
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/social-media-management">
                                                                Social Media Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/performance-monitoring">
                                                                Performance Monitoring
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cyber-security">
                                                                Cyber Security <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/website-maintenance">
                                                                Website Maintenance
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                    </ul>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">SEO Checker</h4>
                                                <div className="sidebar__brochure sidebar__brochure-two">
                                                    <p>Check your website's SEO performance.</p>
                                                    <Link href="/#seocheck">SEO Checker</Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-two">
                                                <div
                                                    className="sidebar__contact sidebar__contact-two"
                                                    data-background="/assets/img/services/sidebar_contact_bg.jpg"
                                                >
                                                    <h2 className="title">
                                                        Contact Us Any Time For Immediate Support!
                                                    </h2>
                                                    <Link href="tel:+14702604117" className="btn">
                                                        <i className="flaticon-phone-call" />
                                                        (470) 260-4117
                                                    </Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">Send Us a Message</h4>
                                                <div className="sidebar__form">
                                                    <form action="#">
                                                        <div className="form-grp">
                                                            <input type="text" name="name" placeholder="Your Name" />
                                                        </div>
                                                        <div className="form-grp">
                                                            <input
                                                                type="text"
                                                                name="phone"
                                                                placeholder="Phone Number"
                                                            />
                                                        </div>
                                                        <div className="form-grp">
                                                            <textarea name="message" placeholder="Type Your Message" />
                                                        </div>
                                                        <button type="submit" className="btn btn-two">
                                                            Send Message
                                                        </button>
                                                    </form>
                                                </div>
                                            </div>
                                        </aside>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <div className="brand-area">
                    <div className="container">
                        <h4 className="brand__content">Trusted by Numerous Companies, Worldwide</h4>
                        <div className="swiper-container brand-active">
                            <BrandActiveSlider />
                        </div>
                    </div>
                </div>
            </Layout>
        </>
    );
}
