import Layout from "@/components/layout/Layout";
import BrandActiveSlider from "@/components/slider/BrandActiveSlider";
import Link from "next/link";

export const metadata = {
    title: "Service Details | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ServicesDetails3() {
    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Services We Provide">
                <div>
                    <section className="services__details-area">
                        <div className="container">
                            <div className="services__details-wrap">
                                <div className="row">
                                    <div className="col-70 order-0 order-lg-2">
                                        <div className="services__details-content services__details-content-two">
                                            <h2 className="title">Social Media Management</h2>
                                            <p>
                                                Maintaining consistently effective posts on a social media account can
                                                be challenging. Many businesses struggle to elevate their presence,
                                                create engaging content, and measure their social media impact
                                                effectively. RankRunners solves these challenges with our comprehensive
                                                Social Media Management services. We will handle every aspect of your
                                                social media strategy, from content creation to analytics, beginning to
                                                end, so you can focus on running your business while we enhance your
                                                online presence.
                                            </p>
                                            <div className="services__details-thumb">
                                                <img src="/assets/img/custom/service-06-01.png" alt="" />
                                            </div>
                                            <div className="services__details-inner-three">
                                                <h3>Benefits:</h3>
                                                <ul>
                                                    <li>
                                                        <strong>Strategic Planning</strong>: We develop tailored social
                                                        media strategies that align with your business goals and target
                                                        audience, ensuring effective engagement and growth.
                                                    </li>
                                                    <li>
                                                        <strong>Content Creation</strong>: Our team produces
                                                        high-quality, relevant content that resonates with your audience
                                                        and reflects your brand’s voice and values.
                                                    </li>
                                                    <li>
                                                        <strong>Consistent Posting</strong>: We ensure regular and
                                                        timely updates across all your social media platforms, keeping
                                                        your audience engaged and informed.
                                                    </li>
                                                    <li>
                                                        <strong>Community Engagement</strong>: We actively manage
                                                        interactions with your followers, fostering positive
                                                        relationships and addressing inquiries or feedback promptly.
                                                    </li>
                                                    <li>
                                                        <strong>Performance Tracking</strong>: Detailed analytics and
                                                        reports provide insights into your social media performance,
                                                        helping us continuously refine strategies for better results.
                                                    </li>
                                                </ul>
                                            </div>
                                            <div className="services__details-inner-two services__details-inner-four">
                                                <div className="gutter-24">
                                                    <div className="col-48">
                                                        <div className="services__details-inner-img float-img">
                                                            <img src="/assets/img/custom/service-06-02.png" alt="" />
                                                        </div>
                                                    </div>
                                                    <div className="col-52">
                                                        <div className="services__details-inner-content-two">
                                                            <h3>Services:</h3>
                                                            <ul>
                                                                <li>
                                                                    <strong>Social Media Strategy Development</strong>:
                                                                    Crafting a comprehensive strategy that outlines
                                                                    goals, target audience, and platform-specific
                                                                    tactics for optimal results.
                                                                </li>
                                                                <li>
                                                                    <strong>Content Creation and Curation</strong>:
                                                                    Designing engaging and shareable content, including
                                                                    graphics, videos, and copy, to captivate your
                                                                    audience and build brand loyalty.
                                                                </li>
                                                                <li>
                                                                    <strong>Account Management</strong>: Handling
                                                                    day-to-day management of your social media profiles,
                                                                    including scheduling posts, responding to comments,
                                                                    and monitoring engagement.
                                                                </li>
                                                                <li>
                                                                    <strong>Social Media Advertising</strong>: Creating
                                                                    and managing targeted ad campaigns to increase
                                                                    reach, drive traffic, and generate leads or sales.
                                                                </li>
                                                                <li>
                                                                    <strong>Analytics and Reporting</strong>: Providing
                                                                    regular reports on social media performance,
                                                                    including metrics like engagement rates, growth
                                                                    statistics, and campaign effectiveness.
                                                                </li>
                                                                <li>
                                                                    <strong>Influencer Collaboration</strong>:
                                                                    Identifying and partnering with relevant influencers
                                                                    to expand your brand’s reach and credibility within
                                                                    your industry.
                                                                </li>
                                                            </ul>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <p>
                                                <strong>
                                                    Initial social media strategy and setup typically take 2 to 4 weeks,
                                                    depending on the complexity and number of platforms. Ongoing
                                                    management and content creation are continuous, with performance
                                                    reviews and strategy adjustments made on a monthly basis.
                                                </strong>
                                            </p>
                                            <div className="all_services__area-six-two">
                                                <div className="container">
                                                    <h3>
                                                        Ready to elevate your social media presence and drive
                                                        engagement?
                                                    </h3>
                                                    <Link href="/schedule" className="btn">
                                                        Start Your Social Media Journey Today!
                                                    </Link>
                                                </div>
                                            </div>
                                            <p>Have questions or need more details? Contact us today:</p>
                                            <div className="contact__info mb-50">
                                                <ul className="list-wrap">
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-phone-call" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Phone</h4>
                                                            <Link href="tel:+14702604117">(470) 260-4117</Link>
                                                        </div>
                                                    </li>
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-mail" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Email</h4>
                                                            <Link href="mailto:support@rankrunners.net">
                                                                support@rankrunners.net
                                                            </Link>
                                                        </div>
                                                    </li>
                                                </ul>
                                            </div>
                                            <h4 className="title-center">
                                                Let RankRunners amplify your social media presence with our expert
                                                management services!
                                            </h4>
                                        </div>
                                    </div>
                                    <div className="col-30">
                                        <aside className="services__sidebar">
                                            <div className="sidebar__widget">
                                                <div className="services-sidebar">
                                                    <ul className="list-wrap">
                                                        <li>
                                                            <Link href="/services/search-engine-optimization">
                                                                Search Engine Optimization
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/ad-campaign-management">
                                                                Ad Campaign Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cloud-computing">
                                                                Cloud Computing <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/lead-generation">
                                                                Lead Generation <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/web-development">
                                                                Web Development/Design
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link
                                                                href="/services/social-media-management"
                                                                className="active"
                                                            >
                                                                Social Media Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/performance-monitoring">
                                                                Performance Monitoring
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cyber-security">
                                                                Cyber Security <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/website-maintenance">
                                                                Website Maintenance
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                    </ul>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">SEO Checker</h4>
                                                <div className="sidebar__brochure sidebar__brochure-two">
                                                    <p>Check your website's SEO performance.</p>
                                                    <Link href="/#seocheck">SEO Checker</Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-two">
                                                <div
                                                    className="sidebar__contact sidebar__contact-two"
                                                    data-background="/assets/img/services/sidebar_contact_bg.jpg"
                                                >
                                                    <h2 className="title">
                                                        Contact Us Any Time For Immediate Support!
                                                    </h2>
                                                    <Link href="tel:+14702604117" className="btn">
                                                        <i className="flaticon-phone-call" />
                                                        (470) 260-4117
                                                    </Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">Send Us a Message</h4>
                                                <div className="sidebar__form">
                                                    <form action="#">
                                                        <div className="form-grp">
                                                            <input type="text" name="name" placeholder="Your Name" />
                                                        </div>
                                                        <div className="form-grp">
                                                            <input
                                                                type="text"
                                                                name="phone"
                                                                placeholder="Phone Number"
                                                            />
                                                        </div>
                                                        <div className="form-grp">
                                                            <textarea name="message" placeholder="Type Your Message" />
                                                        </div>
                                                        <button type="submit" className="btn btn-two">
                                                            Send Message
                                                        </button>
                                                    </form>
                                                </div>
                                            </div>
                                        </aside>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <div className="brand-area">
                    <div className="container">
                        <h4 className="brand__content">Trusted by Numerous Companies, Worldwide</h4>
                        <div className="swiper-container brand-active">
                            <BrandActiveSlider />
                        </div>
                    </div>
                </div>
            </Layout>
        </>
    );
}
