import Layout from "@/components/layout/Layout";
import BrandActiveSlider from "@/components/slider/BrandActiveSlider";
import Link from "next/link";

export const metadata = {
    title: "Service Details | RankRunners - SEO, Web Design & Digital Marketing Agency",
    description:
        "RankRunners provides enterprise level SEO, Web Design/Development, Digital Marketing and IT Management services for companies across all industries, regardless of scope or size. Contact support@rankrunners.net to get started today!",
};

export default function ServicesDetails3() {
    return (
        <>
            <Layout headerStyle={4} footerStyle={3} breadcrumbTitle="Services We Provide">
                <div>
                    <section className="services__details-area">
                        <div className="container">
                            <div className="services__details-wrap">
                                <div className="row">
                                    <div className="col-70 order-0 order-lg-2">
                                        <div className="services__details-content services__details-content-two">
                                            <h2 className="title">Website Maintenance</h2>
                                            <p>
                                                At Rankrunners, we understand the importance of a well-maintained
                                                website for your business's success. Our website maintenance service
                                                ensures your site remains up-to-date, secure, and optimized for
                                                performance, allowing you to focus on your core business activities.
                                            </p>
                                            <div className="services__details-thumb">
                                                <img src="/assets/img/custom/service-09-01.png" alt="" />
                                            </div>
                                            <div className="services__details-inner-three">
                                                <h3>Benefits:</h3>
                                                <ul>
                                                    <li>
                                                        <strong>Enhanced Security</strong>:
                                                        <ul>
                                                            <li>
                                                                Regular security updates and patches to protect your
                                                                website from vulnerabilities and cyber threats.
                                                            </li>
                                                            <li>
                                                                Continuous monitoring to detect and address potential
                                                                security breaches promptly.
                                                            </li>
                                                        </ul>
                                                    </li>
                                                    <li>
                                                        <strong>Optimal Performance</strong>:
                                                        <ul>
                                                            <li>
                                                                Routine performance checks and optimizations to ensure
                                                                your website loads quickly and runs smoothly.
                                                            </li>
                                                            <li>
                                                                Regular updates to website software, plugins, and themes
                                                                for improved functionality and compatibility.
                                                            </li>
                                                        </ul>
                                                    </li>
                                                    <li>
                                                        <strong>SEO Maintenance</strong>:
                                                        <ul>
                                                            <li>
                                                                Ongoing SEO audits and adjustments to maintain and
                                                                improve search engine rankings.
                                                            </li>
                                                            <li>
                                                                Implementation of best practices for on-page and
                                                                off-page SEO to boost visibility and organic traffic.
                                                            </li>
                                                        </ul>
                                                    </li>
                                                    <li>
                                                        <strong>Content Updates</strong>:
                                                        <ul>
                                                            <li>
                                                                Timely updates to website content, including text,
                                                                images, and multimedia, to keep your site fresh and
                                                                relevant.
                                                            </li>
                                                            <li>
                                                                Assistance with content creation and editing to ensure
                                                                your messaging remains consistent and engaging.
                                                            </li>
                                                        </ul>
                                                    </li>
                                                    <li>
                                                        <strong>Technical Support</strong>:
                                                        <ul>
                                                            <li>
                                                                Access to a dedicated support team for troubleshooting
                                                                and resolving technical issues.
                                                            </li>
                                                            <li>
                                                                Regular backups to prevent data loss and ensure quick
                                                                recovery in case of emergencies.
                                                            </li>
                                                        </ul>
                                                    </li>
                                                    <li>
                                                        <strong>User Experience (UX) Enhancements</strong>:
                                                        <ul>
                                                            <li>
                                                                Continuous improvement of website navigation and
                                                                usability for a better user experience.
                                                            </li>
                                                            <li>
                                                                Implementation of responsive design techniques to ensure
                                                                your site looks and functions well on all devices.
                                                            </li>
                                                        </ul>
                                                    </li>
                                                    <li>
                                                        <strong>Analytics and Reporting</strong>:
                                                        <ul>
                                                            <li>
                                                                Detailed monthly reports on website performance,
                                                                traffic, and user behavior.
                                                            </li>
                                                            <li>
                                                                Insights and recommendations based on analytics to help
                                                                you make informed decisions.
                                                            </li>
                                                        </ul>
                                                    </li>
                                                    <li>
                                                        <strong>Compliance and Accessibility</strong>:
                                                        <ul>
                                                            <li>
                                                                Regular checks to ensure your website complies with
                                                                industry standards and regulations.
                                                            </li>
                                                            <li>
                                                                Enhancements to website accessibility, making it
                                                                user-friendly for people with disabilities.
                                                            </li>
                                                        </ul>
                                                    </li>
                                                </ul>
                                            </div>
                                            <div className="services__details-inner-two services__details-inner-four">
                                                <div className="row gutter-24 align-items-center">
                                                    <div className="col-48">
                                                        <div className="services__details-inner-img">
                                                            <img src="/assets/img/custom/service-09-02.png" alt="" />
                                                        </div>
                                                    </div>
                                                    <div className="col-52">
                                                        <div className="services__details-inner-content-two">
                                                            <p>
                                                                By choosing Rankrunners for your website maintenance
                                                                needs, you can rest assured that your online presence is
                                                                in expert hands. We are committed to helping you achieve
                                                                your business goals by keeping your website secure,
                                                                optimized, and performing at its best.
                                                            </p>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <p>
                                                <strong>
                                                    Initial setup and a professional assessment of your company’s
                                                    website(s) typically takes 2 to 4 weeks, depending on the complexity
                                                    of your needs and existing systems. Ongoing maintenance and applying
                                                    any updates are continuous, with as-needed updates and solutions
                                                    provided to keep you safe and secure.
                                                </strong>
                                            </p>
                                            <div className="all_services__area-six-two">
                                                <div className="container">
                                                    <h3>
                                                        Website Maintenance by RankRunners will keep your website ahead
                                                        of the competition. Consult us today!
                                                    </h3>
                                                    <Link href="/schedule" className="btn">
                                                        Consult us Today!
                                                    </Link>
                                                </div>
                                            </div>
                                            <p>Have questions or need more details? Contact us today:</p>
                                            <div className="contact__info mb-50">
                                                <ul className="list-wrap">
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-phone-call" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Phone</h4>
                                                            <Link href="tel:+14702604117">(470) 260-4117</Link>
                                                        </div>
                                                    </li>
                                                    <li>
                                                        <div className="icon">
                                                            <i className="flaticon-mail" />
                                                        </div>
                                                        <div className="content">
                                                            <h4 className="title">Email</h4>
                                                            <Link href="mailto:support@rankrunners.net">
                                                                support@rankrunners.net
                                                            </Link>
                                                        </div>
                                                    </li>
                                                </ul>
                                            </div>
                                            <h4 className="title-center">
                                                Let RankRunners maintain your website so you can worry about doing what
                                                you do best!
                                            </h4>
                                        </div>
                                    </div>
                                    <div className="col-30">
                                        <aside className="services__sidebar">
                                            <div className="sidebar__widget">
                                                <div className="services-sidebar">
                                                    <ul className="list-wrap">
                                                        <li>
                                                            <Link href="/services/search-engine-optimization">
                                                                Search Engine Optimization
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/ad-campaign-management">
                                                                Ad Campaign Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cloud-computing">
                                                                Cloud Computing <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/lead-generation">
                                                                Lead Generation <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/web-development">
                                                                Web Development/Design
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/social-media-management">
                                                                Social Media Management
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/performance-monitoring">
                                                                Performance Monitoring
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link href="/services/cyber-security">
                                                                Cyber Security <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                        <li>
                                                            <Link
                                                                href="/services/website-maintenance"
                                                                className="active"
                                                            >
                                                                Website Maintenance
                                                                <i className="flaticon-arrow-button" />
                                                            </Link>
                                                        </li>
                                                    </ul>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">SEO Checker</h4>
                                                <div className="sidebar__brochure sidebar__brochure-two">
                                                    <p>Check your website's SEO performance.</p>
                                                    <Link href="/#seocheck">SEO Checker</Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-two">
                                                <div
                                                    className="sidebar__contact sidebar__contact-two"
                                                    data-background="/assets/img/services/sidebar_contact_bg.jpg"
                                                >
                                                    <h2 className="title">
                                                        Contact Us Any Time For Immediate Support!
                                                    </h2>
                                                    <Link href="tel:+14702604117" className="btn">
                                                        <i className="flaticon-phone-call" />
                                                        (470) 260-4117
                                                    </Link>
                                                </div>
                                            </div>
                                            <div className="sidebar__widget sidebar__widget-three">
                                                <h4 className="sidebar__widget-title">Send Us a Message</h4>
                                                <div className="sidebar__form">
                                                    <form action="#">
                                                        <div className="form-grp">
                                                            <input type="text" name="name" placeholder="Your Name" />
                                                        </div>
                                                        <div className="form-grp">
                                                            <input
                                                                type="text"
                                                                name="phone"
                                                                placeholder="Phone Number"
                                                            />
                                                        </div>
                                                        <div className="form-grp">
                                                            <textarea name="message" placeholder="Type Your Message" />
                                                        </div>
                                                        <button type="submit" className="btn btn-two">
                                                            Send Message
                                                        </button>
                                                    </form>
                                                </div>
                                            </div>
                                        </aside>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
                <div className="brand-area">
                    <div className="container">
                        <h4 className="brand__content">Trusted by Numerous Companies, Worldwide</h4>
                        <div className="swiper-container brand-active">
                            <BrandActiveSlider />
                        </div>
                    </div>
                </div>
            </Layout>
        </>
    );
}
